#
# spec file for package retroarch
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           retroarch
Version:        1.19.1
Release:        1.4
Summary:        Emulator frontend
License:        GPL-3.0-only
Group:          System/Emulators/Other
URL:            http://www.retroarch.com
Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}_migrate_old_config.py

BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  p7zip
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  unzip
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(SDL2_gfx)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
%if ( 0%{?suse_version} || 0%{?leap_version} )
BuildRequires:  update-desktop-files
BuildRequires:  vulkan-devel
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
%endif

# Xbox One/Series controller wireless driver
Recommends:     xpadneo

%description
RetroArch is a modular multi-system emulator system that is designed to be
fast, lightweight, and portable. It has features few other emulators frontends
have, such as real-time rewinding and game-aware shading.

%prep
%setup -q

# Change /usr/bin/env python to /usr/bin/python
sed -i s~%{_bindir}/env\ python~%{_bindir}/python~g tools/cg2glsl.py

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="$CFLAGS"
./configure --prefix=%{_prefix} \
    --enable-materialui \
    --enable-xmb \
    --enable-sdl2 \
    --enable-udev \
    --enable-threads \
    --enable-thread_storage \
    --enable-ffmpeg \
    --enable-ssa \
    --enable-dylib \
    --enable-networking \
    --enable-networkgamepad \
    --enable-opengl \
    --enable-x11 \
    --enable-xinerama\
    --enable-kms \
    --enable-wayland \
    --enable-egl \
    --enable-zlib \
    --enable-alsa \
    --enable-al \
    --enable-jack \
    --enable-pulse \
    --enable-freetype \
    --enable-xvideo \
    --enable-v4l2 \
    --enable-qt \
    --enable-dbus \
%ifarch x86
    --enable-sse \
%endif
%if ( 0%{?suse_version} || 0%{?leap_version} )
    --enable-vulkan \
%endif
    --enable-7zip \
    --enable-mmap
make %{?_smp_mflags}

%install
%make_install
install -m 0755 %{SOURCE1} %{buildroot}%{_bindir}/%{name}_migrate_old_config

%fdupes %{buildroot}

%post
%{_bindir}/%{name}_migrate_old_config

%files
%config(noreplace) %{_sysconfdir}/%{name}.cfg
%{_bindir}/%{name}
%{_bindir}/%{name}_migrate_old_config
%{_bindir}/%{name}-cg2glsl
%{_datadir}/applications/org.libretro.RetroArch.desktop
%{_datadir}/metainfo/com.libretro.*.xml
%{_datadir}/pixmaps/%{name}.svg
%{_mandir}/man?/%{name}.?*
%{_mandir}/man?/%{name}-cg2glsl.?*
%{_datadir}/doc/%{name}

%changelog
* Sat Jun  8 2024 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.19.1
  * Savestates: Revert savestate changes, was causing corruption and other issues
* Sat Jun  8 2024 Martin Schreiner <martin.schreiner@suse.com>
- Update to version 1.19.1:
  * (WASAPI) Only write when running and fix deadlock.
* Thu May 30 2024 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.19.0
  * AI: Revert AI translation to previous version (fix for translation not working with HW rendered cores)
  * AUDIO: Bring back audio toggling on menu toggle
  * CHEEVOS: Build a default RetroAchievements memory map when no RetroAchievements game is loaded
  * CHEEVOS: Update to rcheevos 11.3
  * CHEEVOS: fix hardcore acting as if it's enabled when it isn't
  * CLANG: Fix clang error incompatible-pointer-types-discards-qualifiers
  * CLOUDSYNC/LINUX: Enable Cloud Sync by default on Linux builds with network (#16456)
  * CORE: Set compute fps stats logging to debug level
  * EMSCRIPTEN: Added M2000 to core selection dropdown
  * FFMPEG: Add compatibility with FFMPEG 7.0
  * GLSLANG: Remove unneeded ENABLE_HLSL code from glslang
  * GENERAL: Memory leak: Dynamic allocation from msg_hash_get_help_us_enum was not freed.
  * INPUT/KEYBOARD: Add support for multimedia keys - Extended RETROK_ values with 18 new items, commonly found on
  "multimedia" keyboards. Mapping added for SDL, X11, Wayland, dinput, winraw keymaps.
  * INPUT/MFI: Pressure sensitive left/right triggers
  * INPUT/MFI: Fix Start + L1/L2/R2 combinations
  * INPUT/MFI: Support strong and weak rumble
  * INTL: Fetch translations from Crowdin
  * INTL: Add Galician and Norwegian to list of languages
  * LAKKA: Display reboot/shutdown message also when not saving config on exit
  * LAKKA: Provide update URL and target name at buildtime
  * LIBRETRO: Add a debug message for the SET_ROTATION callback
  * MENU: New function in Quick Menu: Add to Playlist
  * MENU/XMB: New theme: FlatUX, designed to merge FlatUI and Retroactive themes into a single, unified design
  * NETWORKING/RETROPAD CORE:  Fix socket close method
  * PIXMAN: Update pixman-private.h - patch to fix build issue with musl
  * PLAYLIST: Cleanup 'Add to Playlist' (#16495)
  * SCANNING: Fix for scanning PSP ISOs (and probably few others)
  * SAVES: Fix core config saving
  * SAVES: Fix save new config name when core loaded
  * SAVESTATES: Increase save state chunk size for all platforms - Even a class 6 or class 10 SD card can handle reads and writes on the order of MB/s, which means a 4KB chunk size is just wasting time in syscalls.  This could maybe be fixed with a buffering reader but I don't feel comfortable tweaking libretro-common's VFS to handle that.  Instead, I thought it would be good to both remove an ifdef and increase the chunk size to 128KB.  For cores with small states this will should make state saving virtually instantaneous, and for cores with large states it should be a 32x speedup.
  * VIDEO: Fix crash when using threaded video - for Mesa 23.2 and later
  * VIDEO/GL: Fix reinitialization of the threaded gl drivers
  * VIDEO/VULKAN: Add support for A2R10G10B10 HDR format
  * VIDEO/VULKAN: Implement HDR readback - screenshot support
  * WAYLAND: Ignore configure events during splash (fix not remembering window size)
  * WAYLAND: Use frontend signal handler to quit (fix quit by window close)
  * WAYLAND: Commit viewport resizes (window resize is more responsive)
* Sat Mar 23 2024 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.18.0
  * AI: Fix narrator language when AI translation and menu languages are different
  * DISK CONTROL: Add option to disable initial disk change
  * DISK CONTROL: Visibility option for disk control notifications
  * DRM: Fix mode vrefresh calculation. When using an interlaced/doublescan mode, the vertical refresh rate is mis-calculated.
  * EMSCRIPTEN: Fix mouse Y parameter translation in rwebinput
  * INPUT: Fix input state combos including R3 and false triggers of RETROK_UNKNOWN
  * INPUT: Add a new turbo mode, "Classic (Toggle)"
  * INPUT: Fix bind hold when axis does not rest at 0
  * INPUT: Limit axis threshold setting to sensible values
  * INPUT: Add Overlay Mouse, Lightgun, and Pointer
  * INPUT/ANDROID: Fix mouse grab behavior on Android
  * INPUT/LINUXRAW: Fix device name and hotplug reconnect
  * IOS: Minor iOS JIT availability information
  * IOS/TVOS: Pause application on applicationWillResignActive
  * LIBRETRO: Add Doxygen-styled comments to parts of the libretro API
  * LUA: Update Lua to version 5.3.6
  * MENU: Add sublabels for input bind common entries
  * MENU: Don't load history and favorites if size is 0
  * MENU: Don't disable fast forward when entering menu
  * MENU: Widget position, size, color, icon adjustments
  * MENU: Fix savestate slots in Qt UI
  * MENU: Reorder and reduce depth of User Interface menu
  * MENU/OZONE: Fix sidebar wraparound, visibility after config load, crash after playlist delete
  * MENU/OZONE: Fix sidebar and sublabel animations
  * OSX/MACOS: Fix crash on non-Metal build
  * OSX/MACOS: Add portable.txt as flag for portable install
  * REMOTE RETROPAD: add display for analog axes, indication of inputs already pressed
  * SAVES: Allow combining saves in content dir with save sorting
  * SHADER: Added rolling scan line simulation based on the shader subframe feature. This is implemented with a scrolling scissor rect rather than in the shader itself as this is more efficient although may not work for every shader pass - we may need an option to exclude certain passes. The implementation simply divides the screen up by the number of sub frames and then moves the scissor rect down over the screen over the number of sub frames
  * TVOS: Force asset re-extraction when cache is deleted
  * TVOS: Add history and favorites to Top Shelf
  * TVOS: Fix crash when history item does not have a label
  * UWP: Enable HAVE_ACCESSIBILITY for UWP builds
  * UWP: Allow UWP build to work with a modified version of Mesa Gallium D3D12
  * VIDEO: Add subframe shader support for Vulkan/GLcore/DX10-11-12, enabling shaders to run at higher framerate than the content
  * VIDEO: Fix restoring fullscreen/windowed setting when unloading override
  * VIDEO/VULKAN: Fix HDR with Vulkan after reinit
  * VIDEO/VULKAN: Remove the use of oldSwapchain
  * VIDEO/GL2: Fix OpenGL ES version detection
  * WEBDAV: Fixed SEGFAULT in WebDav task sync + type changes
  * WEBOS: Fix build, add core location on webosbrew.org
  * WIN32: Fix Alt+Enter not working when menubar is disabled
* Sat Mar 16 2024 Yunhe Guo <i@guoyunhe.me>
- Add xpadneo recommends to support Xbox One/Series wireless controllers
* Sun Feb  4 2024 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.17.0
  * ACCESSIBILITY/TTS: fix target language and missing espeak handling on Linux
  * AI: AI service reworked: performance increase, automatic translation, configurable subtitle placement, and more
  * AUDIO/SYNC: Handle Hz skew adjustment for high refresh rates better (BFI, swap interval)
  * AUDIO/MIXER: Separate ffmpeg/mpv and audiomixer conditionals
  * CONFIG/OVERRIDES: Fix setting savefile_directory in override file
  * CONFIG: Force fixed locale for numbers
  * CHEEVOS: Upgrade to rcheevos 11.0
  * CHEEVOS: Use rc_client for state management
  * CHEEVOS: Don't track disc changes when achievements are disabled
  * CHEEVOS: Reinitialize rewind buffer after loading game with achievements
  * CHEEVOS: Inform user when server is unreachable
  * CHEEVOS: Fix crash on first load of game with achievements with threaded video
  * INPUT: Fix ghost input when setting RETROK_UNKNOWN
  * INPUT: Default 'Bind Hold' to 0 to prevent problems with controllers not resting at null state
  * INPUT: Add a setting to allow turbo d-pad directions
  * INPUT: Don't save mouse buttons to autoconfig
  * INPUT/MENU: Add option for merging 'Hotkey Enable' device types
  * INPUT/mFI: disable secondary_joypad to prevent issues with controllers detected both as HID and mFI
  * INPUT/UDEV: Change event detection to polling in udev_joypad
  * INPUT/WAYLAND: Use unaccelerated pointer motion to prevent mouse dead zone
  * LAKKA: Add new menu options for Switch (overclock, CEC, BT ERTM)
  * LIBRETRO: Add environment command to get playlist path
  * LIBRETRO/NETPACKET:
  Switch environment call number from 76 to 78 (retire 76 as it was never used by any core)
  Simplify broadcasts by removing the option to send to all but one client, use an explicit RETRO_NETPACKET_BROADCAST constant instead
  Separate explicit flushing and querying of incoming packet into two operations
  Enable a core to specify a protocol version string which can get used instead of core version to determine compatibility between two players
  Log and notify a separate message when there is a content crc mismatch while using this interface to convey it being less severe
  * MENU: Fix menu analog stick navigation (1.16.0.1)
  * MENU: Add option to find thumbnail images by playlist rom filename (1.16.0.2)
  * MENU: Don't process menu events while input is being flushed (1.16.0.2)
  * MENU: Prevent proceeding to next bind when single binding (1.16.0.3)
  * MENU: Fix touchscreen menu false positives in case of overlap
  * MENU: Sort playlists ignoring extension (Playstation 2 should come after Playstation)
  * MENU: Treat System Volume Information folder as hidden on all platforms
  * MENU: Add Belarusian language option
  * MENU: Fix savestate thumbnail behavior when navigating back to playlist while content is still running
  * MENU: Fix word wrapped widget length
  * MENU: Add help text to controller drivers
  * MENU: Fix quit on content close option
  * MENU: Fix thumbnails in History for content loaded through Load Content
  * MENU: Flexible thumbnail matching (ROM name - database name - short name)
  * MENU: Remove legacy thumbnail pack downloader
  * MENU/GLUI: Icon corrections
  * MENU/OZONE: Thumbnail related fixes (missing thumbnail bar, fullscreen thumbnail flashing, sidebar focus)
  * MENU/RGUI: Fix text scaling in 16:9
  * MENU/XMB: Background images take precedence over color themes, default image opacity set the same as color theme opacity
  * MENU/XMB: Fix segmentation fault when background image is missing
  * MENU/XMB: Several corrections and cleanups
  * MENU/XMB: Layout/thumbnail fixes - Thumbnail layout adjustments, Header title improvements, Handheld layout adjustments
  * NETWORKING/NETPLAY: Add support for joining MITM servers from command line
  * NETWORKING/NETPACKET: Interface connection flow improvements
  * PATCHES: Add support for XDelta-formatted patches.
  * PATCHES: Fix patching for cores that support contentless mode
  * RUNLOOP: Frame Rest, experimental sleep feature aiming to lower CPU usage and temperature when using certain CPU hungry vsync modes
  * SCAN: Do CRC check on PSP/PSP(PSN) content
  * VIDEO/GLSL: Add FinalViewportSize support to GLSL
  * VIDEO/GLSL: Change rotation type to int to maximize compatibility
  * VIDEO: Use video refresh rate instead of core refresh rate for menu frame limiting
  * VIDEO: Limit paused video refresh rate
  * VIDEO: Enforce swap interval 1 in menu if vsync is on
  * WAYLAND: Enable fallback for screensaver inhibit via D-Bus
  * WAYLAND: Introduce wp_fractional_scale_v1 protocol for proper fractional scaling
  * WAYLAND: Update wayland-protocols version to 1.31
* Tue Oct 10 2023 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.16.0
  * AUDIO: Fast-Forward Audio Resampling
  * AUDIO: Reinit audio on audio sync toggle
  * AUDIO: Count audio samples in stats when rate control is disabled
  * AUDIO/PULSEAUDIO: Support device list for PulseAudio
  * ARCHIVE/ZIP: Improve ZIP decompression
  * CHEEVOS: Upgrade to rcheevos 10.7
  * CHEEVOS: Don't initialize rcheevos memory unless used
  * CHEEVOS: Add progress tracker widget
  * CHEEVOS: Eliminate leaderboard tracker stutter
  * CHEEVOS: Expand leaderboard visibility settings
  * CHEEVOS: Collapse trackers with same value definition
  * CHEEVOS: prevent frame step when hitting rewind button while paused in hardcore
  * CHEEVOS: disallow video_swap_interval and black_frame_insertion in hardcore
  * CRT/SWITCHRES: Don't always force core aspect ratio
  * CRT/SWITCHRES: Fix aspect ratio for tate games on a horizontal screen
  * CRT/SWITCHRES: Add PAL threshold option for automatic refresh rate switch
  * CRT/SWITCHRES/KMS: Add KMS modeswitch
  * COMMAND: Make cmd interface more useful for replay information
  * CONFIG: Allow all systems to check for backslashes (Windows) as last slash in path. Improves portable core logic
  * DOWNLOADS/THUMBNAILS: Prevent directory creation on bogus thumbnail downloads
  * EMSCRIPTEN: Fix Emscripten sleep function/macro
  * EMSCRIPTEN/RWEBAUDIO: Fix RWebAudioInit race condition
  * EMSCRIPTEN/OPENAL: Make openal default audio driver
  * FFMPEG: Fix RetroArch fails to restart streaming when video re-inits and instead starts recording
  * FRAMESKIP: Use refresh rate instead of core fps for frameskip timing
  * INPUT: Combo hold + 'enable_hotkey' correction. Fixed issue with having menu toggle hold combo in different button than 'enable_hotkey', which caused 'enable_hotkey' to also act as menu toggle if held long enough, and simplified and unified duplicate code in start+select holds to a single function.
  * INPUT: input_keyboard_event: Don't check hotkey binds when device is RETRO_DEVICE_POINTER
  * INPUT: Add input_keymaps_translate_rk_to_ascii() for correct character input to input_keyboard_event
  * INPUT: input_overlay_poll: Delay clearing INPUT_OVERLAY_BLOCKED flag until there is no overlay input (Avoids stray input after osk_toggle)
  * INPUT: Send keyboard events for modifiers before other keys (for correct modifier+key input if hitboxes overlap)
  * INPUT: Remember currently set keyboard mapping bits during same config read, because otherwise customized keybinds can get cleared out of the bits on the next iteration, causing keyboard events to get passed to the core when they should get blocked.
  * INPUT/AUTOCONFIG: Reinit after updating autoconf profiles
  * INPUT/LINUX/UDEV: Log mouse devices in info level
  * INPUT/LINUX/UDEV: First working version of udev driver with touchscreen support and gestures.
  * INPUT/WAYLAND: Add wayland to input driver list
  * INPUT/MENU: move port X binds into retropad binds submenu and add appropriate help text and sublabels to discourage people from messing around in there unnecessarily
  * INPUT/MENU: Add menu icons to 'RetroPad Binds'
  * INPUT/MENU/OSK: Allow more keyboard actions with menu osk
  * INPUT/REMAP: Remap label fix when no autoconf profile active
  * INPUT/REMAP: Add 'Save As' option for remaps and overrides
  * INPUT/OVERLAY: Add overlay parameter to control x/y separation in auto-scale mode
  * INPUT/OVERLAY: Revive/rewrite Keyboard Overlay and OSK Toggle. Add keyboard overlay preset, keyboard submenu,
    and osk_toggle hotkey. Use overlay caching for osk_toggle.
  * INPUT/OVERLAY: Overlay Caching. Adds overlay_cache_ptr to keep a disabled overlay in memory when it's expected to be shown again.
    Most input_overlay_deinit calls are replaced with input_overlay_unload, which caches the overlay unless initing/deiniting core or disabling overlays.
    Loading a cached overlay is done as a swap, intended for osk_toggle.
  * INPUT/OVERLAY: Add input_overlay_check_mouse_cursor() to preserve show/hide mouse behavior
  * INPUT/OVERLAY: Don't apply input_overlay_show_mouse_cursor in windowed mode (controlled by mouse grab only)
  * INPUT/REMAPPING: Stop always reseting to defaults on remap delete
  * INPUT/SDL: Fix rumble on PS4/PS5 controllers connected via bluetooth
  * INTL: Fix language detection in Canada to English
  * LANGEXTRA: Enable language autodetect for all builds with LANGEXTRA
  * LIBRETRO: Add new context hardware render enums - enables autodetection of DX12 for PS2 core
  * LIBRETRO: Add API to check JIT availability on iOS
  * LIBRETRO: Allow RETRO_ENVIRONMENT_SET_MEMORY_MAPS also after core startup. Change the comment in libretro.h about the removed limit and handle the environment call during core runtime in RetroArch.
  * LIBRETRO/MICROPHONE: Add new API for microphone support.
  * LIBRETRO: Add new API for querying the device's power state.
  * LIBRETRO/VFS: Rewrite retro_vfs_file_remove_impl
  * LINUX: Input driver fix 8+ joypads. It was reported that controllers beyond 8 worked only partially (analogs yes, but not buttons), and the found fix was also confirmed.
  * MIDI: Show MIDI output first
  * MENU: Reorganize 'Saving' menu
  * MENU: Start directory browsing from current value
  * MENU: Fix menu toggle combo hold with same 'enable_hotkey'
  * MENU: Add menu scroll home+end actions
  * MENU: Move 'systemfiles_in_content_dir' from Saving to Core
  * MENU: Menu navigation acceleration adjustments
  * MENU: Audio synchronization menu cleanup
  * MENU: Menu value label cleanup
  * MENU: Show playlist history/favorites icons by default
  * MENU: Remove advanced option flag from video rotation + orientation
  * MENU: Combine audio resampler menu with audio output menu
  * MENU: Microphone menu cleanup
  * MENU: Add missing menu visibility option for content dir override
  * MENU: Fix menu refresh in action_ok_network
  * MENU: Video settings menu cleanup
  * MENU: Try to declutter Quick Menu
  * MENU: Change network port menu options to 'allow_input' mode
  * MENU: Preselect current core in "Set Core Assocation" menu for more carefree usage
  * MENU: Focus back to "Set Core Association" item after returning from the menu instead of first item
  * MENU: Replaced hack fix for focusing the first item after returning from core suggestion "Run" menu after association reset
  * MENU: Fixed setting core association in history/favorites after resetting it and running without setting
  * MENU: Relocate playlist manager core association options to prevent accidental resets with Start
  * MENU: Fraction setting wraparound rounding correction
  * MENU: Add more missing sublabels
  * MENU: 'Updater Settings' relocation
  * MENU: Search box usability improvements
  * MENU/RGUI: Implement 'Remember Selection' option
  * MENU/RGUI: Fix savestate thumbnail fullscreen cancel action
  * MENU/RGUI: Fix and add toggle for playlist thumbnails
  * MENU/OZONE: Update Dracula theme
  * MENU/OZONE: Return to sidebar from playlist manage quick access
  * MENU/OZONE: Sidebar multiline scrolling
  * MENU/OZONE: Avoid crash if ozone sidebar_index_size is 0
  * MENU/OZONE: Prevent metadata and footer overlap
  * MENU/OZONE: Sublabel width tweak
  * MENU/OZONE: Mouse hover selection fix
  * MENU/XMB: Message/help box adjustments
  * MENU/XMB: XMB menu playlist index bugfix
  * MENU/XMB: Playlist label limit fixes
  * MENU/XMB: Prevent playlist label truncating long items even when right thumbnail is not enabled/visible
  * MENU/XMB: Prevent playlist label length resetting to full width on every item change while thumbnail is pending
  * MENU/XMB: Stop showing playlist entry index outside of playlists
  * MENU/XMB: Fix menu focus issue when returning from "Set Core Association" if playlist index is greater than the previous menu
  * MENU/EXPLORE: Prevent flashing when browsing fullscreen thumbnails
  * MENU/EXPLORE: Match label ticker length behavior with playlists
  * MENU/SOUNDS: Fix certain audio drivers from hanging when menu pause is enabled with menu sounds
  * MENU/SOUNDS: Fix menu sounds stopping after fullscreen toggle / video reinit
  * MENU/QT/WIMP: Cleanup Desktop Menu welcome text
  * MENU/OVERLAYS: Reorder overlay menu
  * MICROPHONE: Add support for microphones.
  * MICROPHONE/ALSA: Add `alsa` and `alsathread` microphone drivers.
  * MICROPHONE/SDL: Add `sdl2` microphone driver.
  * MICROPHONE/WASAPI: Add `wasapi` microphone driver.
  * MOBILE: On mobile in portrait mode, don't override custom viewport
  * NETWORKING: Enhance netpacket interface
  * NETWORKING/NETPLAY: Enable core host to refuse connecting new players to limit the number of connected players
  * NETWORKING/NETPLAY: Enable a core to flush outgoing packets and read incoming packets without waiting for the next frame (can be used for lower latency or blocking reads)
  * OPENDINGUX/RG350: Enable networking for RG350
  * OPENGL/WAYLAND: Add frame callback after egl_swap_buffers to improve latency when max_swapchain <= 2
  * OSD/STATISTICS: Show current video + audio drivers in statistics
  * OSD/STATISTICS: Ensure statistics text is aligned left
  * PLAYLIST: Change default playlist last played time format
  * RUNLOOP: Don't count frames while paused
  * SERENITYOS: Add SerenityOS to the list of supported operating systems
  * SCANNER: Improve scanner console output
  * SCANNER: More scanner console output coloring
  * SCANNER: Improve CLI scan console output
  * SCANNER: Add content import/scan via CLI
  * SCANNER/PS1: Serial extraction is now considered a failure if PSX.EXE is found, allowing CRC fallback and actually fixing the game scanning
  * VIDEO: Correct rotated core provided aspect ratio
  * VIDEO: Minor adjustments to refresh rate switch behavior
  * VIDEO: Fix windowed viewport with libretro rotation
  * VIDEO/SDL2: Use "nearest" scaling in menus
  * TASKS: Fix corrupt task progress percentage
  * XVIDEO/MENU: Add menu support to xvideo gfx driver, making it usable
  * UWP: Fix modifier keys ( shift, ctrl, alt ) as well as F10 not being detected on the UWP platform
  * VULKAN: Ignore Fast-Forward Frameskip option
  * VULKAN/KHR_DISPLAY: Support screen refresh rate with Vulkan KHR_Display context
  * WAYLAND: Remove splash screen
  * WAYLAND: Check for pointer before locking it
  * WAYLAND: Add mouse grab/lock functionality
  * WAYLAND: Get system wayland-protocols path via pkg-config
* Mon Mar 20 2023 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.15.0
  * AI SERVICE: Fix NVDA switching to Powershell on speak
  * AUTOMATIC FRAME DELAY: Helped delay to decrease easier when it should and helped delay to stay put when it should when triggering pause & menu with or without pause & fast-forward & slow-motion & geometry change
  * AUTOMATIC FRAME DELAY: Recalibrate delay on video reinit (fullscreen toggle and such)
  * AUTOMATIC FRAME DELAY: Show (x effective) only in menu item and not in dropdown list items when auto is enabled
  * CHEEVOS: Allow repositioning of RetroAchievement notifications
  * CHEEVOS/MENU: Add Achievements Visibility submenu option
  * CHEEVOS/MENU: Startup Summary split off from Verbose Mode, added option to hide for games with zero core cheevos
  * CHEEVOS/MENU: 'Unlocks/Mastery' split into two options
  * CHEEVOS/MENU: 'Account/Login Messages' split off from 'Verbose', gated all login success/error messages
  * CONFIG/INPUT: Unload restores current global config
  * CONFIG/INPUT/OVERRIDES: Removing a file does not unload current override
  * CONFIG/INPUT/OVERRIDES: Saving an empty override removes the file if it exists, and won't save when it does not
  * CONFIG/INPUT/OVERRIDES: Prevent the use of RUNLOOP_FLAG_OVERRIDES_ACTIVE with appendconfig
  * CORE OPTION: Core option setting type checks. Added checks for getting and setting core option type, since otherwise there will be a crash on close content after browsing to core option categories. Also fixed the no-show switch icon for lone wolf "Lock Installed Core".
  * CLI: Update selected save slot when start with cli --entryslot
  * CLI: Decouple config CLI append and config overrides
  * CLI/MENU/XMB: Stop showing bogus previous icon on CLI launch
  * EMSCRIPTEN: Add HAVE_PATCH support for Emscripten
  * EMSCRIPTEN: Add BSV/Replay support for Emscripten
  * EMSCRIPTEN: Add command and stdin_cmd features to emscripten RA. update libretro.js to show how commands could be sent over emscripten stdin.
  * FRAME DELAY/MENU: Show Frame Delay without VSync
  * GENERAL: Start unpause restriction. Limit the feature using retropad start button to unpause RA to the setting it was made for; "pause on controller disconnect".
  * GENERAL: Savestate thumbnail aspect ratio fallback. Thanks to at least one certain core that announces aspect ratio as 0, we have to add the same fallback in savestate thumbnails that is happening elsewhere in normal video driver use anyway.
  * GENERAL: Add support for system subdirs per core/database. Added the trivial and graceful automatic ability to send a different system directory to cores if it exists, for keeping the system dir more sane. First by using the core/library name just like in configs and saves, and then by playlist name, like in thumbnails, and of course default to the current global system dir.
  * GENERAL: Ignore system subdir replacement if subdir has subdirs.
  * GENERAL: Restore cached video driver always on quit
  * LATENCY/PREEMPTIVE FRAMES: Add Preemptive Frames to Latency Settings. RunAhead alternative that reruns core logic to "rewrite history" before the current frame. Frames are only rerun when the controller state changes, so it's faster overall.
  * LATENCY/PREEMPTIVE FRAMES: Call retro_run before retro_serialize (#14893). Fixes preemptive frames not starting up with a few cores
  * LIBRETRO-COMMON/VFS/FILESTREAM: Fixes filestream_vscanf regression
  * LOCALIZATION: Updates
  * LOCALIZATION: Enable localization of video rotation, orientation, and aspect ratio option values.
  * LOCALIZATION: Mixer stream localization also added
  * LOCALIZATION/MENU/HELP: Context dependent help text for audio and video drivers. Language corrections
  * LOCALIZATION/MENU/LANGUAGE: Language submenu now shows the progress of translated strings for each language.
  * LOCALIZATION: Help texts now localizable through Crowdin.
  * LIBRETRO: Enable RETRO_ENVIRONMENT_SET_SUPPORT_NO_GAME for libretro-video-processor
  * LIBRETRO/HW: Add GET_HW_CONTEXT_NEGOTIATION_INTERFACE_SUPPORT. Works around issues in v1 interface where it was not possible to
    query what frontend would do when faces with newer interface versions. This env-call gives stronger guarantees how things have to work.
  * INPUT: Allowing keyboard hotkeys to work without hotkey modifier if modifier is only mapped to RetroPad
  * INPUT: Allowing keyboard hotkey keys for typing if hotkey modifier is set to keyboard but not pressed
  * INPUT: Allowing keyboard RetroPad keys for typing if emulated device type is "None"
  * INPUT/AUTOCONFIG: Check for 'enable_hotkey' also from autoconf binds
  * INPUT/BLUETOOTH: Fix a crash in for BT HID devices. (#14922) pad_connection_destroy() frees slots, no need to free it again.
  * INPUT/BSV/REPLAY: Don't start video recording when BSV recording starts
  * INPUT/BSV/REPLAY: Don't double-record inputs in BSV recording
  * INPUT/BSV/REPLAY: Don't autoload states if a BSV file is being played back or recorded
  * INPUT/BSV/REPLAY: Moved BSV initialization before autoload code
  * INPUT/BSV/REPLAY: Don't trigger autoload code if there is bsv movie state
  * INPUT/BSV/REPLAY: Allow for both -e and -R to start a BSV file recording at a state
  * INPUT/BSV/REPLAY: Add keyboard recording support to BSV
  * INPUT/BSV/REPLAY: Fix BSV playback from a starting state for DOSbox
  * INPUT/BSV/REPLAY: Associate states with replays. Now states can be saved and loaded during replay recording and playback in a way that keeps the integrity of the recording. Recordings also have a (moderately) unique identifier associated with them.
  * INPUT/BSV/REPLAY: Add checkpointing feature for replay recordings. If cores are not deterministic, or if they only have bounded determinism, we can obtain less drift if replay files also contain periodic checkpoint states.  These are configured by the new retroarch setting replay_checkpoint_interval (measured in seconds).  States are inserted into the replay file in between frames. This also fixes the settings display for the replay autoincrement max keep setting.
  * INPUT/FRAMEADVANCE: Use non-rendering pause mode when frameadvance is triggered
  * INPUT/HOTKEYS/OVERLAYS: Do not block input overlay hotkeys
  * INPUT/HOTKEYS: Hotkey blocking correction. Turned out the previous hotkey blocking changes worked properly only with winraw driver and not the rest (at least with Windows), because input_keyboard_event() could be called at the wrong moment, and thus storing keyboard menu press there broke the separation of controller Guide menu button and keyboard menu key. Also allowed the blocking to work in both directions so that controller hotkeys won't get blocked if only keyboard has "enable_hotkey" bind.
  * INPUT/LINUX/UDEV: Fix udev guns input when id_mouse is not id_joystick
  * MENU: Rename 'Standalone Cores' to 'Contentless Cores'
  * MENU: Music files should also obey builtin_mediaplayer_enable (#14967) Disabling the built in media player should be possible for music files
    as well. Without this, sound files can not be opened from file browser with cores that support them.
  * MENU: Relocated items to a more logical order
  * MENU: Corrected some title capitalizations (when/before/after are not low case, but for/the/a are)
  * MENU/AUDIO: Add dropdown menu for audio device
  * MENU/HELP: Help for turbo modes (#14919). Help text added for each of the selectable turbo modes.
  * MENU/INPUT: Add unified back action to all menu drivers. Usability boost for all menu drivers resulting in similar behavior as with Ozone currently, which is pressing back/cancel enough the selection jumps first to Main Menu and when pressed again jumps to the first item, so that when a core is running, Quick Menu is very quickly accessible from anywhere. And when core is not running, the first item would be Load Core.
  * MENU/INPUT: Override bind save + menu manager overhaul
  * MENU/INPUT: Allowed and fixed input bind saving to overrides
  * MENU/INPUT: Overhauled override menu
  * MENU/INPUT: Pressing Start on the top active file entry reloads current overrides as startup would
  * MENU/SUBLABELS: All under "Configuration File" + moved "Reset to Defaults" to bottom
  * MENU/SUBLABELS: Quick Menu > Controls > Port x Controls
  * MENU/SUBLABELS: Port x Controls > Device Type
  * MENU/RGUI: Fix disabled menu item color. The effect was not working properly, since transparency meant using the core output color as background.
  * MENU/XMB: Horizontal icon animation fix
  * MENU/XMB: Fixed playlist manager icons to take Explore Views into account properly
  * MENU/XMB: Changed XMB Explore View title to match Ozone
  * MENU/XMB: Added "Switch Icons" option
  * MENU/XMB: Fix MENU_ACTION_CANCEL when search is active. Nasty issue discovered in XMB which broke search term cancelation.
  * MENU/XMB: Layout corrections:
  * MENU/XMB: More room for longer item labels and values
  * MENU/XMB: "Core Downloader" has extra space for item and "installed" indicator
  * MENU/XMB: Fixed "Menu Scale Factor" to not require restarting to get the actual end result
  * MENU/XMB: Adjusted scale factor to behave better with both layouts
  * MENU/XMB: Fixed savestate thumbnails and adjusted vertical fade factor in "Handheld" layout
  * MENU/XMB: Changed thumbnail shadow to outline and tightened fullscreen thumbnail margins
  * MENU/XMB: Adjusted global shadow opacity
  * MENU/XMB: Remove "Framebuffer opacity" from XMB as it does not use it. Also, rename the corresponding menu title, since "framebuffer" is not that intuitive.
  * MENU/OZONE: Fixed playlist manager icons to take Explore Views into account properly
  * MENU/OZONE: Refresh thumbnail on close content hotkey
  * MENU/OZONE: Ozone footer enhancements (#14926). Add Help button (Select) and Reset to Default (Start) to footer where applicable.
  * MENU/OZONE: Ozone footer enhancements (#14934). Display Help footer only if there is actual info to be displayed, either actual help, or sublabel if it is not visible otherwise.
  * MENU/OZONE: Ozone footer enhancement: Scan button (#14949). Display Scan button in footer when it is applicable.
  * MENU/OZONE: Add Clear button to Ozone footer (#14947). Add indication of Clear button when it is applicable (currently: keybinds).
  * MENU/MATERIALUI: Added missing Favorites+History icons in playlist manager
  * MENU/MATERIALUI: Added "Switch Icons" option
  * MENU/CHEATS: Added missing icons in cheats (Delete + Copy After/Before)
  * MENU/CHEATS: Fixed label capitalization in cheats (Add New After/Before This)
  * MENU/SOUNDS: Add scrolling sounds for RGUI, XMB, MaterialUI and Ozone.
  * MENU/SOUNDS: Better scrolling sound implementation, add new 'notice back' sound
  * MENU/SOUNDS: Scroll sound fixes. Correctly get list size in xmb.c for playing scrolling sound when switching categories, play the scrolling sound when pressing cancel in ozone, play the sound when scrolling with ZL and ZR, play the correct sound when scrolling with L- MIYOO: L3/R3 support for Dingux Gamepad controller device.
  * MENU/WIDGETS: Show square sized widget on volume mute. Volume widget is currently fixed size always, and thus showing a lot of empty space when muting, therefore shorten the box to icon size only when muting.
  * NETWORKING: Call ssl_socket_close for SSL sockets
  * NETWORKING/CHEEVOS: net_http - Temporary fix for cheevos crash. Don't use new timeout/poll code for cheevos HTTP requests.
  * NETWORKING/MENU: Network information cleanup:
  * NETWORKING/MENU: Remove extra space from : delimiter
  * NETWORKING/MENU: Trim useless/duplicate garbage from the end of ipv6 address. Windows shows %%[adapter number], Linux shows %%[adapter name], which already shows before the address
  * NETWORKING/STDIN: Add LOAD_STATE_SLOT N command to stdin/network protocol
  * OSD/STATISTICS: Add Run-Ahead data to on-screen statistics
  * OSD/STATISTICS: Notification font + statistics adjustments
  * OSD/STATISTICS: Finetuned statistics layout to be more compact and aligned
  * OSD/STATISTICS: Group Run-Ahead and Frame Delay as "Latency"
  * OSD/STATISTICS: Try to scale font as small as possible/readable if stats won't fit
  * OSD/STATISTICS/FONT: Allow reseting notification font with RetroPad Y to "null", which uses the fallback pixel font
  * OSD/STATISTICS/FONT: Show "Default" instead of empty with default font
  * QB/CONFIGURE: Add new flags - HAVE_UPDATE_CORE_INFO, ASSETS_DIR, FILTERS_DIR
  * RECORDING: Add recordings to video history playlist
  * REWIND: Don't take rewind steps while menu pause active
  * RUNLOOP: Currently when core is paused, video output will be stopped completely too, making it impossible to animate widgets while paused, therefore:
  * RUNLOOP: Added a new runloop state for pause which renders last cached frame
  * RUNLOOP: Allowed rewinding while paused so that it acts like backwards frameadvance. Also moved rewind step taking before menu iteration so that steps won't be lost while in menu when menu_pause is disabled
  * RUNLOOP: State load and reset while paused will forget pause for x frames in order to show proper output
  * RUNLOOP: Allowed reading pause hotkey while menu is active
  * RUNLOOP: Allowed reading screenshot hotkey while menu is active
  * RUNLOOP: Joined 2 fullscreen hotkey checks to one (Any ideas why they were separated for paused and non-paused states, since one works fine for both..?)
  * RUNLOOP: Implement GET_HW_CONTEXT_NEGOTIATION_INTERFACE_SUPPORT. Fairly trivial. Just report the latest version.
  * SAVESTATES: State slot hotkey adjustments -
  * SAVESTATES: Allow selecting -1 Auto slot with hotkeys
  * SAVESTATES: Allow wrap-around from -1 to 999 and backwards
  * SAVESTATES: Show failure message when trying to load a state that does not exist instead of plain "Loading state"
  * SAVESTATES: Shorten the duration of slot change notification
  * SAVESTATES: Change the widget type to the same type as shader toggle for better back and forth action. Closes [Widgets] Save state slot switcher
  * SHADERS: Append Preset feature
  * SHADERS: Prepend Preset feature
  * SHADERS: Shader Preset - Wildcard Replacement in Paths on Load. When a simple preset loads, text wildcards which are found in paths inside the presets will be replaced with values coming from the current RetroArch context. The replacement will be executed on both texture paths and reference paths.
  * VIDEO: Allow manual video swap interval forcing. The addition of auto swap interval effectively prevented manual forcing, which is beneficial when the rate is not reported properly. Therefore use the interval in the calculation only when using automatic interval.
  * VULKAN: Fix crash when using multiple physical devices and HW core (#14889)
  * VULKAN: Detect if wrong PhysicalDevice is returned.
  * VULKAN: Actually query physical device before creating core device.
  * VULKAN: Define and implement v2 of context negotiation interface
  * VULKAN: Add v2 of context negotiation interface.
  * VULKAN: Add vkEnumerateInstanceVersion symbol.
  * VULKAN: Implement v2 context negotiation
  * VULKAN: Use compute shaders to upload RGB565
  * VULKAN: Fix regression with RGB565 and OriginalHistory.
  * VULKAN/WAYLAND: Don't clamp the number of requested images. Due to an unfortunate "feature", MESA always reports 4 as the Vulkan surface's minImageCount in Wayland.
    However, values of 2 and 3 work perfectly well, even if they are out of spec, providing way better latencies when using the Vulkan backend on Wayland.
    So this removes the artificial clamping that was being done to desired_swapchain_images, because it's not really necessary and was causing very noticeable input lag on Wayland+Vulkan.
  * VULKAN/MENU/RGUI: Fix RGUI on Vulkan on platforms that don't have _pack16 VkFormats
  * VULKAN/MACOS/OSX: avoid using _PACK16 pixel formats on platforms without them
  * WAYLAND: On scaled desktops the wayland backend deciding to resize based on values multiplied by the scale factor twice. Resulting in continuous attempts to rebuild the swapchain when in fullscreen.
  * WAYLAND: Wait for splash screen configuration. Before, configuration (resize) events for the initial wayland window could happen before or after set_video_mode which could result in a small or corrupted window. Now we make sure that the initial window has processed it's resize events before window size is set by set_video_mode.
  * WAYLAND: Changes the initial window to show a RetroArch logo copied from the icon of the X11 backend.
  * WAYLAND: Build pointer-constraints and relative-pointer protocols.
  * WAYLAND/GL: GL is sometimes not rescaling property (Super + Left).
* Sat Dec 17 2022 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.14.0
  * AUDIO/COREAUDIO/APPLE: Allow coreaudio3 driver to work with audio devices that have 2 or more output channels
  * CHEEVOS: Fix construction of Cheevos badge path
  * CLI: Fixed not getting any output when running --version or --features without --verbose
  * CLI: Fixed crash when running empty - parameter (it proceeded to content loading)
  * CLI: Reformatted --features to require less rows and to be more consistent
  * CLI: Added -V shorthand for --version
  * CLI: Tab removal + whitespace nits
  * CONFIG/MIDI: Prevent MIDI startup error with old configurations
  * DATABASE/EXPLORE/VIEW: Bugfix - RGUI did not clear thumbnail on non-playlist items such as Save and Delete
    menu_explore_get_entry_playlist_index() returns -1 on invalid entries, but the variable where it was stored was unsigned
  * DATABASE/EXPLORE/VIEW: Bugfix - XMB+Ozone cleared thumbnail in Quick Menu when navigating away from Run
  * FASTFORWARD: Restore framelimit on fastforward toggle. Fast-forward was broken after toggling vrr_runloop off, since it will force frame limit to 1.0 (even on every frame) and never restores it. So let's make sure the wanted ratio is applied when toggling FF (Fastforward).
  * FFMPEG CORE: Fix runtime error in FFmpeg core when build with FFmpeg n5.1.2 and OpenGL ES
  * GFX/VIDEO FILTERS: (picoscale_256x_320x240) Added snn function to upscale Fuse (ZX Spectrum) core borderless output to 320x240. ZX Spectrum resolution of 256x192 was previously unsupported.
  * HOTKEYS: Further reorder internal hotkey items for consistency and removed SEND_DEBUG_INFO, OVERLAY_NEXT and OSK from visible hotkey bind list. "Send Debug Info" stuff is removed as much as possible without breakage due to translation files.
  * INPUT/AUTOCONFIG: Disable 'pause on controller disconnect' by default - was enabled by default on 1.13.0
  * INPUT/MENU: Device Index menu refactor
  * INPUT/OVERLAY: Fix analog drift blocking touch input (could occur on overlay_next if physical inputs shown on overlay)
  * INPUT/OVERLAY: Fix overlay_next buttons lighting up in unison
  * INPUT/OVERLAY: Skip meta keys in input_overlay_add_inputs (not supported by input_state_internal)
  * LEAPFROG: Add Leapfrog (LFx000) Target
  * LOCALIZATION: Updates
  * LOCALIZATION/INPUT/IME/MENU/ONSCREEN KEYBOARD: Extended IME and Korean OSK
  * MENU: Cleanup of help texts
  * MENU: Allow toggling info off with the same button
  * MENU: Allow menu wallpaper/background reset. Let's also remove the current wallpaper from the screen when pressing Start.
  * MENU: Null driver shows with different color (Added for all menus the ability to show "disabled" items with a muted color)
  * MENU/DRIVERS: Menu driver first, Audio Resampler removed because it is enough to exist under audio settings
  * MENU/INPUT: Moved "Confirm Quit" to Input menu
  * MENU/INPUT/HOTKEYS: Input hotkey menu completely overhauled to keep related entries together, and also adjusted some labels and sublabels
  * MENU/OVERLAY: Fix overlays behind menu without core running. "Show Overlay Behind Menu" is currently broken with Ozone and XMB (with any other color theme than Plain) when running without a core.
  * MENU/MATERIALUI: Fix home screen on first startup - no more stray entries
  * MENU/OZONE: Allowed drawing sidebar and thumbnail bar background color also when core is running
  * MENU/OZONE: Stopped using different padding and position for savestate thumbnails vs imageviewer
  * MENU/OZONE: Removed gradient background effect when core is running, because some themes already have gradient background, which creates ugly rough steps
  * MENU/OZONE: Fixed "Gray Light" theme from using the same background as "Gray Dark", which makes selection cursor near impossible to see
  * MENU/OZONE: Some whitespace corrections
  * MENU/UX: Extend OFF menu value colors
  * MENU/UX: Menu icon improvements - Menu Visibility icons (Quick Menu + Settings)
  * MENU/UX: Menu icon improvements - Playlist Manager icons
  * MENU/UX: Menu icon improvements - Explore icon as database icon
  * MENU/UX: Menu icon improvements - View and filter icons as cursor icon (folder icon in GLUI)
  * MENU/UX: Menu icon improvements - View save + delete icons
  * MENU/UX: Menu icon improvements - Moved Explore + Views below Standalone Cores
  * MENU/UX/OZONE: Removed icons from menus where others items don't have icons, and added icons to menus where the rest have icons
  * MENU/UX/OZONE: Changed the way "no icon" is handled from kludgy way of not drawing SUBSETTING icon
  * MENU/UX/XMB: Changed playlist entry index positioning to bottom right when thumbnails are in vertical mode, because big lists will overlap with arrow and current "breadcrumb" icons when the position is next to current selection
  * MENU/UX/XMB: Added a rather nasty hack to prevent showing wrong icons under Explore as "breadcrumb" icon
  * MENU/UX/XMB: Optimized certain icon drawing loops (Main horizontal icons were looped even when not visible, and all previous "breadcrumb" icons were looped when only one certain was needed)
  * MENU/UX/MATERIALUI: Fixed showing icons where there should not be any (Waitable Swapchains, Show Recording + Streaming)
  * SDL GFX: Fix no menu on start/blank screen issue.
  * SRAM: Don't init SRAM saving without content (gets rid of the redundant logging)
* Mon Nov 21 2022 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.13.0
  * CHEEVOS: Upgrade to rcheevos 10.5
  * COMPILATION: Fixed compiling with --disable-menu
  * CONFIG: Don't show override notification with appendconfig alone
  * DATABASE/PLAYLISTS: Playlist + database changes - Cleanup 'entry_slot', fallback label + logging
  * FRONTEND: Fix default remaps folder for various cores: remap should be nested in config folder
  * GFX/VIDEO FILTERS: Prevent video filter init if game is not running
  * HOTKEYS: Fix shader toggle and add hotkey + sublabel
  * HOTKEYS: Cleanups and corrections - Keep hotkey pause and menu pause separate in order to not trigger unwanted pause when toggling menu regardless if menu will pause or not
  * HOTKEYS: Cleanups and corrections - Allow unpausing with Start (makes resuming more convenient after controller disconnect if menu does not pause)
  * INPUT: Fixed the way devices were previously indexed. Input devices were only being indexed in order and would stop at the first time an input has no device connected to it. The problem is when a device gets disconnected, that input will have no devices connected to it, but the next input may still have a device connected. So, that makes changing the port of the currently connected devices impossible.
  * INPUT/AUTOCONFIG: Add option for pause on controller disconnect
  * INPUT/AUTOCONFIG: Driver independent disconnection notification. Should show disconnect notification now properly on Windows with XInput and/or DirectInput pads
  * INPUT/HID: Added usb hid controllers for the famous ZeroDelay encoder and also for "Kade: Kick Ass Dynamic Encoder" to be able to use some custom arcade sticks.
  * INPUT/OVERLAY: Add eightway area types.
  * INPUT/OVERLAY: Ignore hitboxes with zero area. I.e. Set 'reach_x' or 'reach_y' to zero to ensure no hitbox math is done. This simplifies designating animation-only descriptors (e.g. for eightway areas) or obsolete descriptors.
  * INPUT/OVERLAY: Add 'reach' and 'exclusive' for hitboxes. Allows stretching hitboxes and handling their overlap.
  * INPUT/OVERLAY: Fix overlay next_index for unnamed targets
  * INPUT/MENU: Addition to analog stick menu navigation
  * INPUT/MENU: Enable menu navigation also with right analog stick
  * INPUT/MENU: Add option for swapping menu scrolling buttons
  * LOCALIZATION: Updates
  * LOCALIZATION: Add Hungarian language option
  * MENU: Thumbnail fullscreen toggle behavior correction
  * MENU: Consistent left-right scrolling for Quick Menu items
  * MENU: Remove useless sublabel from System Information
  * MENU: Improve widget appearance with missing assets
  * MENU/QT/WIMP: Remove SSL/TLS check at startup
  * MENU/OZONE: Show metadata helper in footer only with second thumbnail
  * MENU/OZONE: Footer improvements - Add "Cycle thumbnails" helper when suitable
  * MENU/OZONE: Footer improvements - Show "Search" helper only when search function is enabled
  * MENU/OZONE: Footer improvements - Fix "Thumbnails available" helper for save states
  * MENU/OZONE: Footer improvements - Tighten padding between icon and title, and widen between helpers
  * MENU/OZONE: Launching anything from a View no longer throws Quick Menu off the screen
  * MENU/OZONE: Save state thumbnails in slot dropdown obeys fullscreen toggle properly when content launched via CLI
  * MENU/OZONE: Save state thumbnail dropdown won’t allow fullscreen toggle when it shouldn’t
  * MENU/OZONE: Selection position remembering in non-playlists won’t flash the first entry
  * MENU/OZONE: Remember selection per main tabs
  * MENU/OZONE: Remove incomplete assets warning
  * MENU/OZONE: Add option to adjust cursor memory when changing menu tabs
  * MENU/OZONE: Further extend texture support for Core Option categories
  * MENU/XMB: Remove incomplete assets warning
  * MENU/XMB: Add truncate playlist name option
  * MENU/XMB: Improve background image selector
  * MENU/XMB: Add option to adjust cursor memory when changing menu tabs
  * MENU/XMB: Further extend texture support for Core Option categories
  * MENU/MATERIALUI: Remove incomplete assets warning
  * QB: Don't fail if OSDependent/OGLCompiler libraries are not present
  * SCANNER/PS1: Improved scanning of PS1 discs
  * SCANNER/PS2: Added serial scanning of PS2 discs - should now scan DVDs and other discs which were previously missed
  * THUMBNAIL: If you rename title, you cannot use the thumbnail image. because the thumbnail filename and the title must be the same.
    If there is no thumbnail with title, find the thumbnail image with rom-name. This has nothing to do with IME.
  * THREADED VIDEO/GLCORE: Fix regression 'Shader presets dont load, when video driver is set to glcore'
  * VULKAN: Fix HDR inverse tonemapping. Only skip tonemapper if HDR10 is explicitly enabled by last shader pass. Otherwise, we are simply just inheriting the bit-depth of the swapchain.
* Sun Nov  6 2022 Yunhe Guo <i@guoyunhe.me>
- Remove --enable-libusb because of upstream change
- Update to version 1.12.0
  * CONFIG/CLI: Allow use of --appendconfig with override cfgs instead of getting ignored
  * CONFIG/LOGGING: No more console startup logging if logging to file
  * CONFIG: Saves config on exit only once instead of (worst case scenario) 3 times
  * DATABASE/EXPLORE/VIEW: Add View feature - Add saving of a filter set in the Explore menu into a so called "View" file which then gets listed alongside playlists. This also adds the ability to filter a category by range in the Explore menu and not just filter on exact matches.
  * FILEBROWSER: Fix regression - certain extensions keep disappearing
  * IOS: New modern iOS version (targeting iOS 13 and up), leverages Swift
  * IOS: Fixes to iOS toolbar
  * IOS16: Add iOS 16 lock screen widget
  * IOS13+: Added emulator keyboard
  * IOS13+: Add JIT support for non-jailbroken devices
  * IOS13+: Added support for touch mouse handler
  * IOS13+: Changed click-and-drag behavior to double tap hold and drag
  * INPUT/HAPTIC/OVERLAYS/ANDROID: Improve haptic feedback for input overlays
  * LINUX/MALI FBDEV: Add conditional support for OpenGL ES 3.x
  * LOCALIZATION: Updates
  * LOCALIZATION/ENGLISH: Add British English language option
  * LOGGING/QT: Increase log buffer to 2048 characters - Vulkan validation layer
    messages output correctly now.
  * MENU/XMB: Remember selection per main tabs. Addresses the following : collection playlists can contain hundreds or thousands of items. When scrolling through one, pressing left or right by accident can be common. This resets the playlist to the top
  * MIST/STEAM/STEAMDECK: Don't expose Black Frame Insertion (BFI) if we are running on a Steam Deck
  * NETWORKING/WINDOWS: Disable poll support for MSVC 2010 and earlier. WSAPoll is not supported on Windows XP and earlier.
  * NETWORKING/WIIU: Fix socket_connect_with_timeout for WIIU
  * NETWORKING/WIIU: Fixes RetroAchievements login
  * NETWORKING/WIIU: Fixes other online updater functionality
  * SAVESTATES/NOTIFICATIONS: Add delay to savestate notifications, so that GPU savestate screenshots stay untouched
  * SAVESTATES/SCREENSHOTS: Avoid 'video_gpu_screenshot' with savestates. Allow GPU screenshots with savestates only when there is no other way of getting a screenshot.
  * SCREENSHOTS/VULKAN: Unload screenshot widget texture early. Fixes Vulkan crash when closing content while a screenshot widget is still on-screen
  * SCREENSHOTS/VULKAN: Fix screenshot widget crash when ticker animating
  * WAYLAND: Set correct app ID
  * WIIU: Add some missing default directories
  * WIIU: Get mkdir working on WiiU (directory creation)
* Thu Apr 21 2022 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.10.3
  * AI/SERVICE: Disable AI Service setting by default
  * BLUETOOTH/LAKKA: bluetoothctl: add / modify pairing steps
  * CHEEVOS: Disallow manual frame delay setting in Hardcore Mode
  * DATABASE: Serial scanning for Wii now includes WBFS
  * INPUT: Allow proper descriptor declaration for analog triggers
  * INPUT/MAPPING: Fix offset + crash when clearing input port binds
  * INPUT/MAPPING: Fix saving of 'Analog to Digital Type' when configuration overrides are used
  * INPUT/MAPPING: Fix saving of 'Analog to Digital Type' when configuration overrides are used
  * LOCALIZATION: Add Valencian language option
  * LOCALIZATION: Updates
  * MENU/SETTINGS: Move 'Show Menu Bar' under 'Windowed Mode' settings
  * MENU/SETTINGS: Add sublabels for 'Subsystems' and 'Input Deadzone/Sensitivity'
  * MENU/SETTINGS: Move 'On-Screen Notifications' to top
  * MENU/XMB: Unified the shadow alpha value to a slightly darker one for better readability
  * MENU/XMB: Corrected the option label and sublabel for actual behavior
  * STATIC PLATFORMS: Populate all history list metadata when launching content from playlists
  * VIDEO: Fast-Forward Frameskip improvement
  * VIDEO/THREADED: Stability fixes
* Sat Mar 26 2022 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.10.2
  * CHEEVOS: Update to rcheevos 10.3.3
  * CHEEVOS: Support for Arduboy
  * CHEEVOS: Fix tab sequences in rich presence being turned into t
    character
  * CHEEVOS: Fix overflow when parsing float value that has more than
    9 digits after the decimal
  * CHEEVOS: Fix memory mapping when disconnect mask breaks a region
    into multiple blocks
  * CORES: Enable manual selection of which cores are displayed in
    the 'Standalone Cores' menu
  * DATABASE/EXPLORE: Added more categories to the Explore menu
  * INPUT: Fix analog stick not working with 'Unified Menu Controls'
  * INPUT/MAPPING: Add 'Manage Remap Files' submenu + automatically
    save input remaps when closing content
  * INPUT/MAPPING: Add 'Reset Input Mapping' option to 'Manage Remap
    Files' menu
  * INPUT/MAPPING: Fix keyboard device remap nulling
  * LIBRETRO: RETRO_ENVIRONMENT_SHUTDOWN fix - ensure core is properly
    unloaded when RETRO_ENVIRONMENT_SHUTDOWN is called
  * LIBRETRO: RETRO_ENVIRONMENT_SHUTDOWN fix - ensure menu stack is
    properly flushed when RETRO_ENVIRONMENT_SHUTDOWN is called
  * LINUX/MALI FBDEV: Fix segfault switching video threaded from
    quickmenu
  * LOCALIZATION: Add Czech language support
  * MENU/SETTINGS: Remove 'Advanced Settings' flag from 'Settings >
    Core' menu
  * MENU/MATERIALUI: Add 'Gray Dark + Light' themes
  * MENU/RGUI: Add 6x10 extended ASCII and Latin Extended A and B
    fonts. These will enable most Latin alphabets to be displayed in RGUI.
  * MENU/RGUI: Add 'Gray Dark + Light' themes
  * MENU/XMB: Add title margin adjustment
  * MENU/XMB: Vertical fade corrections
  * MENU/OZONE: The size of the thumbnail bar can now be changed though
    a new option (Settings->User interface->Appearance) up to double
    its normal size.
  * MENU/OZONE: Add 'Gray Dark + Light' themes
  * MENU/OZONE: Add thumbnail scale option
  * HOTKEYS: Added hotkey for toggling sync to exact content framerate
  * HOTKEYS: Prevent log spam when using rewind hotkey with cores
    that don't support rewind, if rewind functionality itself is disabled
  * HOTKEYS: Add hotkey for toggling sync to exact content framerate
  * VIDEO/HDR: Removed redundant copy of buffer in HDR mode if the
    shader has already a HDR format i.e. R10G10B10A2 (updated
    Vulkan/D3D11/D3D12 drivers)
  * VIDEO/HDR: Fixed crash when using stock shader and HDR and
    previous optimisation
  * WAYLAND: Dynamically load libdecor at runtime
  * WAYLAND: Fix splash screen when using xdg_toplevel
  * WAYLAND: SHM anti-collision for the splash screen
  * WAYLAND: Skip splash screen if window is not ready
* Sat Mar  5 2022 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.10.1
  * Network fixes
  * Logging fixes
* Sat Feb 19 2022 Yunhe Guo <i@guoyunhe.me>
- Remove retroarch-config.patch and use upstream config and updater
- Remove cores dependencies and prefer downloading from upstream
- Add retroarch_migrate_config.py and run it after installation
- Update to version 1.10.0
  * ARCHIVE: Allow loading files from archive subdirectory
  * AUDIO: Remove frame limit from audio batch callback. Before, if
    a core used the audio batch callback, there would be a hidden
    cap of 1024 on the number of audio frames that could be sent. If
    a core exceeded this value, any excess samples were silently
    discarded. While this is sufficient for 'normal' samplerates/
    framerates, it means that e.g. a core using the batch callback
    to send 44100 Hz audio at 30 fps with would have entirely broken
    sound. This has been fixed by removing the audio batch frame limit.
  * AUDIO/RESAMPLER/NEON: Implement sinc kaiser NEON function
  * CHEEVOS: Reset hardcore default to enabled; show message when
    trying to load state in hardcore
  * CHEEVOS: Fix memory map conversion
  * CHEEVOS: Check netplay status when unlocking achievements
  * CHEEVOS: Support for hashing buffered NDS ROMs
  * CHEEVOS: Fix hung task whe badge doesn't exist
  * CLI: Load save states from command-line or playlist
  * CORE INFO CACHE/SETTINGS: Restore missing 'Cache Core Info Files'
    menu entry
  * DATABASE: Serial scanning for Gamecube/MegaCD/SegaCD/Saturn/PSX
    /PSP/Dreamcast/Wii
  * EMSCRIPTEN: Add Jaxe, WASM4 cores
  * FILE IO: Fix incorrect file names for remap files when the
    content path doesn't have a preceding slash
  * INPUT/OVERLAY: Added support for showing the overlay behind the
    menu instead of in front. This is currently only supported on
    the GL, Vulkan, D3D 9/10/11/12 and 3DS drivers.
  * INPUT/UDEV: Convert abs mouse from screen to viewport coordinates;
    fix relative mouse coords
  * INPUT/WAYLAND: Ignore mouse clicks on window decoration
  * INPUT/WAYLAND: Add scroll wheel support
  * LINUX: Added support for Linux GameMode (https://github.com/FeralInteractive/gamemode),
    which can be toggled on/off in the Power Management or Latency settings menus.
  * LOCALIZATION: Fetch translations from Crowdin
  * LOCALIZATION: Add Indonesian, Swedish and Ukrainian language options
  * LOCALIZATION/MENU/RGUI: Enable Indonesian and Swedish localisations
    for RGUI
  * LOGGING: Logging cleanups
  * LOGGING: Stop logging FPS statistics twice on quit
  * LOGGING: Log font rendering backend only once
  * HOTKEYS: Added a hotkey toggle for the on-screen technical statistics.
  * HOTKEYS: Add delay + acceleration to volume hotkeys
  * MENU: Add option for showing notifications only in menu
  * MENU/RGUI: Add Finnish to supported languages
  * MENU/XMB: Optional vertical list item fade
  * MENU/XMB/OZONE: Category + History/Favorites icons
  * NETWORK: Fix dummy notification - no longer shows a netplay
    initialization failed notification when netplay is not enabled
  * NETWORK: LAN addresses only for UPnP - Some router devices
    might accept non-LAN addresses without raising an error.
  * NETWORK: Filter out non-connectable rooms. Add an option for
    filtering out non-connectable netplay rooms.
  * NETWORK: Netplay spectator notification fix. Fix double
    notification when the host switches to spectator.
  * NETWORK: Prevents long-term pausing from clients dishonoring
    allow pausing
  * NETWORK/LOBBY: Lobby Viewer: Filter out rooms that are not
    running RetroArch
  * NETWORK/LOBBY: Lobby Viewer: Display a non-connectable tag to
    non-connectable rooms
  * NETWORK/LOBBY: Host: Display warning if we are announcing to
    the internet but our room isn't connectable from there
  * NETWORK/RELAY: Custom relay server support - Add support for
    custom user-ran relay servers
  * NETWORK/RELAY: Replace Canadian relay server with Singapore
    relay server. Current relays: New York/USA, Madrid/Spain, Sao
    Paulo/Brazil, Singapore
  * NETWORK/UPNP: Various refactors/improvements, no more dependent
    on miniupnpc
  * NETWORK/UPNP: Various UPnP binding fixes for specific routers
  * NETWORK/UPNP: Accept IGD v2 service types
  * NETWORK/UPNP: Delay lobby server announcing - delay the announcing
    in order to give UPnP's port forwarding more time. Fix the remaining
    truncation warnings.
  * NETWORK/UPNP: Smart interface selection - Find the most suitable
    address for UPnP by scoring interfaces on how close their address
    is to the device's address
  * OPENGL1: Fix buffer overflow - RetroArch would sometimes crashes
    at startup when loading asset textures with GL1 driver
  * VULKAN: Double combined image sampler descriptor pool size -
    fix segfaults with AMD GPUs using RADV
  * VULKAN: Emulate mailbox only with Vsync enabled - otherwise
    have it disabled - useful for VRR/G-Sync/FreeSync
  * VULKAN/SWAPCHAIN: Vulkan max swapchain images option adjustments:
    removed value 1, since it won't be used - Video reinit on change,
    so that there is no need to restart or toggle fullscreen
  * VULKAN/HDR: HDR support - tested on Windows
  * WAYLAND: Add libdecor for client side decoration
  * WAYLAND: Use any display for initial metrics
  * WAYLAND: Fix the window closing, if RetroArch is build without libdecor
  * WAYLAND: Use checked sizes in EGL resize
  * WAYLAND: Fix window title update
  * See full changelog at https://github.com/libretro/RetroArch/blob/master/CHANGES.md
* Sun Oct 31 2021 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.9.12
  * COMMAND: Command interface should work again
  * INPUT/HID: Rewrote the HID deregistration algorithm; it should
    no longer cause issues when dealing with multiple pads of the
    same HID/VID combo
  * INPUT/HID: Fix initialization bug that caused wiimotes to fail
    to register without an accessory attached
  * INPUT/HID: Fix Wiimote regression
  * INPUT/UDEV: Add extra abs check for dolphinbar
  * INPUT/UDEV: Add relative left mouse button when pointer device
    is not abs
  * INPUT/WAYLAND: Fix keyboard input on Wayland - fixes 'Certain
    cores ignore user input'
  * NETPLAY: Improvements from Cthulhu
  * LIBRETRO: Enable SRAM for contentless cores
  * LIBRETRO: Add environment callback to get the rate retro_run is
    called - GET_THROTTLE_STATE and RETRO_THROTTLE_UNBLOCKED
    environment callback
  * LINUX: Update metadata manifest
  * MENU/OZONE: New themes - Solarized Light, Solarized Dark
- Update to version 1.9.11
  * INPUT: Refactor menu toggle combo button logic to allow quit
    combo button
  * INPUT/UDEV: Add mouse relative check and set appropriately to
    fix issue
  * LIBRETRO: Add environment callback to enable cores to notify
    the frontend that a core otion value has changed
  * STEAM/LINUX: Move to new 'soldier' runtime
  * WAYLAND: Remove xdg-shell-v6 protocol
- Update to version 1.9.10
  * AUDIO/MIXER: Pad sample buffers to prevent potential
    heap-buffer-overflows when resampling (fixes crash when using
    30 kHz menu audio files)
  * AUDIO/LINUX/SNAP: Add JACK support
  * CHEEVOS: Don't write achievement credentials to overrides
  * CHEEVOS: Disable slowmotion when enabling hardcore mode
  * GFX/WIDGETS: New regular widget message appearance
  * INPUT/MOUSE: Add distinct mouse zero index label for drivers
    that do not support multimouse
  * INPUT/RUMBLE: Add generic rumble gain to input settings
  * INPUT/UDEV/X11: Add workaround to fix keyboard input when
    using X11 + Udev
  * LOCALIZATION: Fetch translations from Crowdin
  * OPENDINGUX/BETA: Disable OpenAL
  * PLAYLISTS: Add 'Refresh Playlist' option
  * VIDEO/REFRESH RATE: Automatic PAL/NTSC refresh rate switch
    where available - as long as the platform display server allows
    changing refresh rates and the display has the desired refresh
    rate
  * VIDEO FILTERS: Add 'Picoscale_256x-320x240' video filter
* Thu Sep  9 2021 Yunhe Guo <i@guoyunhe.me>
- Update to version 1.9.9
  * AUDIO/MIXER: Ensure than menu sounds are re-enabled when calling
    CMD_EVENT_AUDIO_REINIT
  * AUDIO/RESAMPLER/MIXER: Fix menu sounds (audio mixing) when using
    the 'sinc' resampler with quality lower than 'normal'
  * AUDIO/CONVERSION/ARM NEON: Add intrinsic NEON versions for
    float_to_s16/s16_to_float - should lead to optimized codepaths
    for AArch64/ARMv7 architectures without being dependent on ASM
    codepaths.
  * AUDIO/RESAMPLER/ARM NEON: Add intrinsic NEON version for lanczos
    sinc function - should lead to optimized codepaths for AArch64/ARMv7
    architectures without being dependent on ASM codepaths.
  * CHEEVOS: Upgrade to rcheevos 10.2
  * CHEATS: Add enhanced search functionality to the 'Cheats' menu
  * CHEATS/RUNAHEAD: Fix cheats when using second instance runahead
  * CONFIG: Add option to (force-)write current core options to disk (Quick Menu)
  * CORE INFO CACHE: Remove core path from core info cache. Should
    make core info caches portable now (for example: you can move
    RetroArch to a separate dir and they would still work).
  * INPUT/OVERLAY: Fix overlay input when analog to digital mapping
    is enabled
  * INPUT/UDEV: Look for "ID_INPUT_KEY", not "ID_INPUT_KEYBOARD"
  * INPUT/WINRAW: Fix crash when overlay is enabled
  * MENU: Allow 'Custom Aspect Ratio (X Position)/(Y Position)/(Width)/(Height)'
    to be entered manually via keyboard
  * MENU: Allow 'Vertical Refresh Rate' to be entered manually via keyboard
  * MENU/SHADERS: Highlight currently selected value in Shader Parameter drop-down lists
  * STABILITY: Safer way of avoiding the race condition in
    audio_driver_sample/audio_driver_sample_batch - we can check
    audio-suspended to see if we're doing a fs/windowed toggle - enhances
    stability when fullscreen toggling/tearing down context
  * STABILITY: When audio driver write callback function fails, don't
    turn audio off completely - look if audio_driver_output_samples_conv_buf
    is non-NULL first before we attempt to write audio - enhances stability
    when fullscreen toggling/tearing down context
  * STABILITY: Input robustness for cores that use internal threading
    (full teardown/setup), no audio should be processed at this point in
    time
  * VIDEO: Screen resolution list sanitizing
  * VULKAN: Fix some Vulkan validation layer errors
* Sun Jul  4 2021 i@guoyunhe.me
- Remove unused --disable-git_version build option
- Update to version 1.9.6:
  * ARCHIVE: Fix archive delimiter detection when file path contains no slashes
  * AUDIO/XAUDIO2: Fail instead of crashing when disconnecting an audio device
  * CHEEVOS: Reset cached progress each time menu is opened
  * CRT/SWITCHRES: Add support for switchres.ini core and directory overrides
  * GFX: Fix uninitialized variables in gfx_display_draw_cursor
  * HISTORY: Hide 'Add to Favorites' when viewing an entry of the favorites playlist
  * INPUT: 'Analog to Digital Type' usability improvements
  * INPUT: Add support for mapping multiple controllers to a single input device
  * INPUT/REMAPPING: Add support for mapping multiple controllers to a single input device
  * INPUT/LIGHTGUN: Bind lightgun trigger to first mouse button by default
  * INPUT/WINDOWS/RAWINPUT: Mouse access violation fix
  * INPUT/UDEV: Only add mouse if it has buttons and add vebose device friendly names
  * INPUT/UDEV: Skip mouse with no button errors and keep the rest
  * INPUT/UDEV: Fix Game Focus mode
  * INPUT/UDEV/X11: Change udev driver for dual lightgun support in X11
  * LOCALIZATION: Fetch translations from Crowdin
  * LOCALIZATION: Fix Switchres menu texts
  * MENU/OZONE: Ensure sidebar display status is updated correctly when performing rapid menu navigation
  * MENU/XMB: Dynamic wallpaper fix
  * MENU/XMB: Icon opacity fix
  * MENU/QT/WIMP: Fix default core detection when playlist file name does not match 'db_name'
  * PLAYLISTS: Optimise scanning of large rom sets
  * SECURITY: Plug so-called high-risk vulnerability related to Powershell - avoid injection - don't send speech input as commandline argument
  * X11: Fix threaded video segfault
* Fri Apr 30 2021 alexandre.vicenzi@suse.com
- Update to version 1.9.1:
  * Update CHANGES.md
  * Update CHANGES.md
  * Update CHANGES.md
  * Update CHANGES.md
  * (iOS6) Add assets.zip/modules dir
  * OpenDingux: Improve handling of unsupported display resolutions + buffer overflow fix
  * (shader_gl_core) Cut down on some std::string usage
  * Bump up version (but don't tag yet)
  * (iOS6/iOS9) Take out HAVE_UPDATE_CORES
  * Relocate 'Menu Scroll' settings
* Wed Aug 12 2020 Yunhe Guo <i@guoyunhe.me>
- Change recommended PlayStation core:
  * libretro-beetle-psx-hw for x86 and ppc
  * libretro-pcsx-rearmed for arm
* Sun Aug  9 2020 Yunhe Guo <i@guoyunhe.me>
- Change broken libretro-blastem to libretro-picodrive
* Sat Aug  8 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.9.0
  * Full changelog at https://github.com/libretro/RetroArch/blob/master/CHANGES.md#190
- Add libretro-glsl-shaders recommends
* Tue Jun 23 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.9
  * Full changelog at https://github.com/libretro/RetroArch/blob/master/CHANGES.md#189
* Thu May 28 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.8
  * Full changelog at https://github.com/libretro/RetroArch/blob/master/CHANGES.md#188
* Sat May 23 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.7
  * Full changelog at https://github.com/libretro/RetroArch/blob/master/CHANGES.md#187
- Fix python shebang
* Fri May 15 2020 Yunhe Guo <i@guoyunhe.me>
- Remove libretro-mame core recommendation due to performance issue
  and package size (100+MB)
- Add libretro-gme and libretro-gw core recommendation
* Thu May  7 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.6
  * Full changelog at https://github.com/libretro/RetroArch/blob/master/CHANGES.md#186
* Wed Mar 25 2020 Karol Sławiński <karol_slawinski@wp.pl>
- Version 1.8.5
  * Full changelog at https://github.com/libretro/RetroArch/blob/master/CHANGES.md#185
* Wed Feb 19 2020 Yunhe Guo <i@guoyunhe.me>
- Add more core recommends
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  allow OBS to shortcut through -mini flavors.
* Wed Jan 22 2020 Yunhe Guo <i@guoyunhe.me>
- Exclude unneeded lib directory with license issues
* Wed Jan 15 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.4
  * Full changelog at https://github.com/libretro/RetroArch/blob/master/CHANGES.md#184
* Fri Jan 10 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.3
* Wed Jan  1 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.2
- Recommend more available cores
- Remove --with-man_dir parameter to fix build
* Wed Nov  6 2019 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.1
- Added pkgconfig(xxf86vm) build dependency
- Update retroarch-config.patch:
  * Enable online updater, so users can download some game content
* Sat Oct 26 2019 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.0
* Thu Oct 24 2019 Yunhe Guo <i@guoyunhe.me>
- Enable DBus to solve screen off issue during game play
* Thu Oct  3 2019 Yunhe Guo <i@guoyunhe.me>
- Add recommends for Atari, MAME, Nintendo, Sega, Sony emulator cores
* Mon Sep 30 2019 Yunhe Guo <i@guoyunhe.me>
- Update retroarch-config.patch
  * Revert system_directory to default. It must be a writable location
    for some cores. Otherwise, games cannot be loaded.
* Tue Sep 24 2019 Yunhe Guo <i@guoyunhe.me>
- Update retroarch-config.patch
  * Disable menu_show_online_updater because thumbnails will be
    downloaded on demand and all other content should be provided
    by RPM packages
  * Set rgui_browser_directory to user home instead of system root
  * Enable network_on_demand_thumbnails option
  * Set system_directory so we can package some core system files
* Sun Sep 22 2019 Yunhe Guo <i@guoyunhe.me>
- Recommends:
  * libretro-core-info
  * libretro-database
  * libretro-nestopia
  * libretro-bsnes
  * libretro-mgba
  * libretro-gambatte
* Sun Sep 22 2019 Yunhe Guo <i@guoyunhe.me>
- Add retroarch-config.patch to disable in-app updates and enable
  system assets directory
- Remove retroarch.desktop because it is already in source tarball
* Fri Sep 20 2019 Yunhe Guo <i@guoyunhe.me>
- Update to 1.7.8.4
  * Update AndroidManifest.xml
- Update to 1.7.8.3
  * Update CHANGES.md
- Update to 1.7.8.2
  * Update CHANGES.md
- Recommend retroarch-joypad-autoconfig and retroarch-assets
* Mon Sep  2 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add pkgconfig(Qt5Concurrent) to BuildRequires
- Add pkgconfig(Qt5Network) to BuildRequires
- Drop %%{_datadir}/retroarch directory from %%files section
- Drop deprecated --enable-python parameter from configure line
* Wed Aug 28 2019 Marcus Meissner <meissner@suse.com>
- updated to 1.7.8
  * 3DS: Fix C-Stick y-axis inversion
  * 3DS: Update all icon/banner images
  * AI: Add AI Service functionality (enabled for Windows/Mac/Linux/Android/iOS).
  * APPLE (MAC/IOS/TVOS): Fix autodetect for mFI controllers: properly call autodetect add on the connect notification, and add call to disconnect on GameController disconnect notification.
  * ANDROID: Implemented multi-touch touchscreen support
  * ANDROID: Now can be built with Gradle/Android Studio
  * AUDIO/WINDOWS: You can now select between audio devices for XAudio2/DirectSound/XAudio2 by pressing left/right on the Audio Device option.
  * AUDIO/WINDOWS: Setting the device by either index number or name string should work.
  * BLISS-BOX: Add 4 new pad types from firmware 3.0
  * BPS/UPS: Re-allocation target_data variable for target patch size (can now apply bigger patches without extra-bytes on memory)
  * CDROM: Added real CD-ROM functionality for Windows and Linux.
  * CDROM: Added disc dumping.
  * COMMON: Add separate frontend logging
  * COMMON: Ability to set FPS update interval (used in the window titlebar/FPS widget)
  * COMMON: Add 'Reset Frame Time Counter' functionality, enable it by default for resizing the window, loading/saving shader presets, fastforwarding, etc.
  * COMMON: Add optional 'on demand' thumbnail downloads
  * COMMON: Add new playlist-based thumbnail downloader. Hide the legacy thumbnail pack version by default
  * COMMON: Show license per core (if available) inside 'Load Core'
  * COMMON: Add option to load content from (and dump) CD-ROM discs
  * COMMON: Re-enable '--log-file' command line option
  * COMMON: Default playlist core association is now stored as metadata inside each playlist
  * COMMON: Fix playlist format detection
  * COMMON: Favorites playlist size can now be set independently of content history size. Values can be set from 0-999, or '-1' for unlimited (99999)
  * COMMON: Prevent adding new items to favorites when playlist is full (old entries are no longer overwritten)
  * COMMON: Prevent loading content with cores that require an incompatible graphics API version from the current one
  * COMMON: Saved shader presets are now portable across platforms and use relative paths
  * COMMON: Add '--set-shader' command line option which works like an override for automatic shader presets
  * COMMON: Add global shader presets
  * COMMON: Remove 'video_shader' setting, shaders are not saved automatically anymore
  * CORE OPTIONS: When saving core option overrides, only include settings for the current core
  * CORE OPTIONS: Add option to save core options per-core
  * CPU FILTERS: Add Scanline2x filter
  * DINPUT: Cleanup magic numbers mess surrounding hat code
  * GAMECUBE: Add default video/audio filter directories
  * GL/MALI400: Fix menu issues on Mali 400 series GPUs, should also fix 'RetroArch flickers black on ARM Mali GPUs (Android/ARM Linux)
  * GL/GLCORE: Use highest supported OpenGL Core version on Windows and X11
  * GL1: Ignore alpha in core video, fixes XRGB8888 rendering in some cores
  * GLCORE: Don't hardcode shader cross compilation target version but poll it. glcore would always only use the minimum target shader version, i.e. GLSL ES 3.00 for OpenGL ES 3.0+ or GLSL 1.50 for OpenGL 3.2+
  * D3D10/11/12/SLANG: Added "FrameDirection" slang semantic. Works fine with braid-rewind shader, not entirely perfect with D3D12 though
  * D3D10/11/12: Add option to select which GPU to render with
  * D3D10/11: Fix maintaining aspect ratio when resizing window
  * GLCORE/SLANG: Added "FrameDirection" slang semantic
  * HID: Add Retrode support. Should work on Wii/WiiU.
  * INPUT: Menu toggle hotkey can now be bound to another keyboard key and it will toggle properly
  * IOS: Correctly centers screen on iPhone X landscape
  * IOS: Implemented multi-touch touchscreen support
  * IOS: Add in more Apple Model numbers for RetroRating Added in all current Apple Model numbers and set a base rating of 19
  * IOS: Remove pause indicator; show the native UI menu using 4-finger swipe down gesture
  * IOS: Support L3/R3 in iOS 12.1, Options buttons in MFi/PS4/XBox One controllers in iOS 13
  * LIBRETRO: Add new core options interface, allows for localization, sublabels and more
  * LIBRETRO: Add new bitmask input codepath, for RETRO_DEVICE_ID_JOYPAD only for now
  * LOCALIZATION: Update Korean translation
  * LOCALIZATION: Update Japanese translation
  * LOCALIZATION: Update Portuguese Brazilian Translation
  * LOCALIZATION: Update Polish translation
  * LOCALIZATION: Update Turkish translation
  * MENU: Add smooth ticker text
  * MENU: Ability to hide every settings submenu (User Interface -> Views -> Settings)
  * MENU: Ability to hide nearly every quick menu entry (User Interface -> Views -> Quick Menu)
  * MENU: Fix longstanding menu display issues on Mali400 GPUs (on ARM hardware, SBCs and mobile phones/tablets)
  * MENU: Fix Record -> Streaming Quality, and Record -> Recording Threads settings
  * MENU: Fix history playlist navigation after running content
  * NENU: Menu entry performance optimisations
  * MENU: Add option to show 'remove playlist entry' only on history/favourites
  * MENU: Overhaul content 'Information' menu display
  * MENU: Add new 'Playlist Management' submenu. Allows default core associations to be set (via dropdown list), and all existing associations to be reset
  * MENU: Add 'Set Core Association' option to Quick Menu
  * MENU: Add option to remain in menu after saving/loading states
  * MENU: Pressing the Start button on 'Load Core' will unload the core.
  * MENU: After a core is running, Load Core will be hidden from view until you select 'Close Content' from the Quick Menu.
  * MENU/WIDGETS: All widgets are now properly cleaned up, fixing the frozen widgets bug when loading / closing content
  * MENU/WIDGETS: Fix crash with tasks
  * MENU/WIDGETS: Widgets are now drawn above the overlay with OpenGL and Vulkan
  * MENU/WIDGETS: Fine tune progress bar colors
  * MENU/WIDGETS: Have the progression widget always resize
  * MENU/THUMBNAILS: Ensure that displayed thumbnails are always refreshed correctly after selecting 'Download Thumbnails' from Quick Menu
  * MENU/THUMBNAILS: Make PNG image loading/processing non-blocking on non-threaded systems
  * MENU/OZONE: Add it for PS3
  * MENU/OZONE: Fix regression in 1.7.7 - OSX/macOS - was unable to start it
  * MENU/OZONE: Fix sublabel spacing
  * MENU/OZONE: Add toggle to enable/disable playlist name truncation in Ozone
  * MENU/OZONE: (Ozone) Fix display of (semi-)transparent thumbnails
  * MENU/XMB: Add menu animation settings
  * MENU/XMB: Add optional thumbnail scaling
  * MENU/XMB: Fix display of long sublabels. Text that would exceed the display area now scrolls line-by-line
  * MENU/XMB/OZONE: Add optional thumbnail upscaling
  * MENU/QT/WIMP: Add core option sublabels as tooltips, add buttons to reset one/all core options
  * MENU/QT/WIMP: Word-wrap core option tooltips
  * MENU/QT/WIMP: Path selector fixes
  * MENU/RGUI: Enable playlist display on platforms without database support
  * MENU/RGUI: Make particle effects framerate independent + add animation speed setting
  * MIDI: correct pitch bend in ALSA driver - MIDI standard pitch bend center position is 0x2000 but ALSA's is 0
  * MIDI: Fix SysEx handling. We need to clear the event status after each message. Otherwise, after a SysEx message the first byte of the next event will incorrectly inherit its delta_time. This causes a delay of several seconds in nearly every MT-32 games which uses a lot of long SysEx.
  * METAL/SLANG: Added "FrameDirection" slang semantic
  * NETBSD: Audioio is now the default audio driver
  * NETBSD: Fix a segfault when starting RetroArch with an empty configuration file and LANG unset in the environment
  * OSD: OSD is now drawn above the overlay with Vulkan
  * OSX: Fix regression with Cocoa GL - shader / preset loading was getting stuck in an infinite loop
  * OSX: Add improved menu resizing for window resizing
  * PLAYLISTS: Add history/favourites to 'Playlist Management' menu
  * RECORD: Fix Twitch streaming
  * REMOTE RETROPAD: Fix for Remote RetroPad input - fixes processing of Remote RetroPad input. None of the remote inputs are being executed both in menu and in game. This is due to the way current key binds are being detected which block processing of any remote input. It's been tested using Remote RetroPad core on Android including digital dpad and analog control input.
  * RUNAHEAD/MSVC2010:  Build in runahead support for MSVC2010 and up
  * RUNAHEAD/VITA: Build in runahead support for Vita version
  * SAVESTATES: Allow auto save states also in cores that support no content as long as some content is loaded
  * SCALER: Fix SSE2 path for ARGB/BGRA -> BGR24 - should fix screenshots being taken for XRGB888 (viewport)
  * SCANNER: Skip all databases with incompatible file extensions, whether content is inside an archive or not
  * SCANNER: Fix hang on empty files inside archives
  * SHADERS: Add proper shader compatibility checks
  * SHADERS: Enable Cg shaders for D3D9
  * SHADERS: Remove 'video_shader' setting, replace it with global presets that make more sense
  * SHADERS: #reference directive for shaders. Presets can point to other existing presets if they are unchanged
  * SHADERS: Will attempt to cache the shader/preset into memory before loading to avoid costly getline/gets/getc operations
  * SHADERS: New --set-shader commandline option
  * SHADERS/MENU: Prevent undefined behaviour when failing to load shaders
  * SHADERS/MENU: Pressing the Start button on 'Load Shader Preset' will reset all shader passes and apply changes, effectively disabling the shaders
  * SHADERS/MENU: New menu options for removing shader presets (global/core/parent/etc).
  * SWITCH :Add Audren audio driver.
  * SWITCH: Fix splitting and joining of joycon controllers. Before this fix, splitting and joining of joycons only ever worked sporadically
  * SWITCH: Proper x/y scaling for pointer devices, fixes touch lightgun
  * THUMBNAILS: Add optional On-Demand Thumbnails.
  * UDEV: Fix wrong udev devices order
  * UDEV/X11: Mouse pointer should work now in X11 environment with no Display
  * VITA: Update Vita2D
  * VULKAN/SLANG: Added "FrameDirection" slang semantic
  * VULKAN: Add option to select which GPU to render with
  * VULKAN: Validate non-causal filter chain for texture inputs. We only validated for UBO inputs apparently.
  * WINDOWS: Menubar should no longer be disabled when threaded video is enabled
  * WINDOWS: Add improved menu resizing for window resizing
  * WINDOWS: Properly set initial directory for menubar 'Load Core' option
  * WII: Add default video/audio filter directories
  * WII: Fix RGUI display corruption
  * WII: Fix HID joypad drivers
  * WII: Add optional overscan correction
  * WII: Fix recursive path_mkdir() operations
  * WII: Add widescreen RGUI support
  * WIIU: Scale menu to viewport size; respect filtering settings for menu
  * WIIU/RGUI: RGUI does its own transparency effects in the texture, so we don't have to add another 50%% on that
  * WIIU/RGUI: Use correct pixelformat ordering for menu texture
  * WIIU/SLANG: Added "FrameDirection" slang semantic
  * X11: Add improved menu resizing for window resizing
  * X11: Add non-evdev keycodes to fix keyboard input on non-Linux systems with X11
* Tue May 21 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- update to version 1.7.7
  * 3DS: Add unique IDs to prevent cores overwriting each other.
  * 3DS: Fix screen tearing when running 50Hz content.
  * ANDROID: We now target API level 26 (minimum is still API level 9).
  * ANDROID: Add option to vibrate on touch (works in menu or overlay).
  * ANDROID: Add device vibration option for cores that support rumble.
  * ANDROID: Add gamepad vibration support for cores that support rumble.
  * ANDROID: Allow stylus/pen to move mouse without pressing down.
  * AUDIO: Avoid deadlocks in certain audio drivers when toggling menu sounds on.
  * BLISS-BOX: Support PSX Jogcon (requires firmware 3.0).
  * CHEEVOS: Fix crash when reading memory that is out of range.
  * CHEEVOS: New Cheevos implementation enabled by default.
  * CHEEVOS: Pop-up badges when an achievement is triggered.
  * CRT: Dynamic super resolution support.
  * DISCORD: Fix potential crash when username is empty and discord is disabled.
  * DISCORD: Ask to join support for Linux.
  * INPUT/ANDROID: Add "Input Block Timeout" option.
  * COMMON: For platforms without HAVE_THREADS, don't automatically resume content when saving/loading states
  * COMMON: Make playlist sorting optional and consistent.
  * COMMON: Fix sorting of playlists with blank labels.
  * COMMON: Fix content scanner creating false positive playlist entries that also have wrong label and crc32.
  * COMMON: Add some MMX-optimized pixel conversion routines.
  * COMMON: Fix typo preventing some SSE2-optimized pixel conversions from being used.
  * COMMON: Add option to track how long content has been running over time.
  * COMMON: Fix buffer overflows in system information.
  * COMMON: Add option to change screen orientation via the windowing system (Android, Windows, X11).
  * COMMON: Show CPU model name in log.
  * COMMON: Add "Help -> Send Debug Info" option (and F10 hotkey) to send diagnostic info to the RetroArch team for help with problems.
  * COMMON: Show GPU device name/version in log.
  * COMMON: Add menu option to write log info to a file.
  * COMMON: Add subsystem support for playlists. Subsystem info is automatically saved to the history playlist for easy relaunching.
  * GL: Add new "gl1" OpenGL 1.1 compliant video driver for legacy GPUs and software renderers
  * GL: Add a new "glcore" driver with slang support (requires GL 3.2+ or GLES3).
  * GL: Draw OSD on top of overlay.
  * GONG: Add savestate support.
  * GONG: Add video refresh rate core options.
  * GONG: Two player support via core option.
  * GUI: Fix text alignment when using stb_unicode.
  * GUI: Fix text display issues when using Japanese (and other unicode-dependent language) text with stb_unicode.
  * GUI: Set language on first startup to the user's preferred OS language (Windows, *nix and Android).
  * INPUT: Add (scaled radial) analog deadzone and sensitivity options.
  * LIBRETRO: Add Turkish language support.
  * LIBRETRO: Allow non-accelerated video to rotate the display.
  * LOCALIZATION: Update Chinese (Simplified) translation.
  * LOCALIZATION: Update Chinese (Traditional) translation.
  * LOCALIZATION: Update Dutch translation.
  * LOCALIZATION: Update French translation.
  * LOCALIZATION: Update German translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Polish translation.
  * LOCALIZATION: Update Russian translation.
  * LOCALIZATION: Update Spanish translation.
  * LOCALIZATION: Add new Turkish translation.
  * MIDI: Fix startup crash in midi driver.
  * MENU: Bugfix - you can no longer get stuck in Online Updater
  * > Update Core screen when toggling between ingame and menu.
  * MENU: Selectively hide 'Take Screenshot' for video drivers
    that don't support taking screenshots.
  * MENU: Framerate independent menu rendering. MaterialUI/Ozone/
    XMB/RGUI can now run at higher framerates.
  * MENU: Thumbnails work in history list.
  * MENU: Menu widgets.
  * MENU: Add memory statistics support to more context drivers.
  * MENU: Enable ozone driver for UWP builds.
  * MENU: Add optional "looping" menu text ticker with configurable speed.
  * MENU: Fix core video rendering when using ozone with GL cores that
    implement the scissor test.
  * MENU: Add optional playlist sublabels (associated core + play
    time, where available).
  * MENU: Dropdown list settings now apply immediately.
  * MENU: Add setting to require pressing the "Exit RetroArch"
    hotkey twice to confirm.
  * MENU: Now able to run at higher refresh rates than 60Hz.
  * MENU: Enable "Add to Favorites" without loading a core.
  * MENU: Allow core name to be hidden on history/favorites playlists.
  * MENU: Populate crc32 and db_name fields when adding history/
    favourites playlist entries.
  * MENU: Fix TTF files not showing in OSD/menu font selection screen.
  * MENU: Fix audio/video filters not showing in file browser.
  * MENU/MaterialUI: Add subsystem support.
  * MENU/MaterialUI: Add currently selected entry in dropdown menus.
  * MENU/OZONE: Add mouse support on entries (no sidebar yet).
  * MENU/OZONE: Allow collapsing the sidebar.
  * MENU/OZONE: Add thumbnail support.
  * MENU/OZONE: Battery notifications.
  * MENU/OZONE: Add wifi icon for network entries.
  * MENU/QT/WIMP: Add git version and build date to Help->About window.
  * MENU/QT/WIMP: Fix content loading via the file browser.
  * MENU/QT/WIMP: Add new settings window to control all RetroArch settings.
  * MENU/RGUI: Improve playlist titles.
  * MENU/RGUI: Add option to hide associated cores in playlists.
  * MENU/RGUI: Add internal upscaling option.
  * MENU/RGUI: Add subsystem support.
  * MENU/RGUI: Add menu sublabel support.
  * MENU/RGUI: Re-enable "Load Core" option when content is loaded.
  * MENU/RGUI: Add optional "Collections" entry to main menu.
  * MENU/RGUI: Add "Lock Menu Aspect Ratio" option.
  * MENU/RGUI: Add "full width" layout option.
  * MENU/RGUI: Ensure menu color theme is applied immediately.
  * MENU/RGUI: Fix "Lock Menu Aspect Ratio" option when using custom viewports.
  * MENU/RGUI: Add widescreen support.
  * MENU/RGUI: Allow text to be centred when selecting widescreen layouts.
  * MENU/RGUI: Add inline playlist thumbnail support.
  * MENU/RGUI: Add optional shadow effects.
  * MENU/RGUI: Performance optimizations.
  * MENU/RGUI: Add optional extended ASCII support.
  * MENU/RGUI: Add optional delay when loading thumbnails.
  * MENU/RGUI: Add on-screen keyboard.
  * MENU/RGUI: Battery notifications.
  * MENU/XMB: Prevent crashes when resizing to a tiny window.
  * MENU/XMB: XMB honors the 'show menu sublabels' setting
    now - was previously RGUI only
  * NETPLAY: Fix stall-out causing total disconnection with >2 players.
  * NETPLAY: Different (more intuitive?) default netplay share policy.
  * NETPLAY: Add hotkey option to toggle hosting on/off.
  * NETWORKING: Encode URLs to allow for spaces in directory names.
  * OSX: Prevent crash on exit.
  * OSX: Metal is now the default video driver for the RetroArch Metal build.
  * OSX: Enable CoreAudio v3 driver for Metal.
  * OSX/MACOS/IOS: Now uses the STB Unicode font driver.
  * PS2: CDFS support.
  * PS2: Implemented analog support for ps2 controllers.
  * PS2: Fix audio freeze after restarting core.
  * PS2: Fix issues with load state and the font driver.
  * PS2: File I/O now works for USB and network host.
  * PS2: Support cores with extra padding in their frame buffers.
  * SCANNER: New option 'Scan without core match'. When this is enabled,
    supported extensions by all installed cores are not checked, and instead
    it will add all content it finds to a playlist. This way, you can install
    the core you need later on after scanning. Not enabled by default.
  * SHADERS: Don't alphabetize shader presets.
  * SWITCH: Add rumble support.
  * SWITCH: Add USB keyboard support.
  * VITA: Add bluetooth mouse and keyboard support.
  * VULKAN: Fix color issues with RGBA8888 swapchains in readback (screenshots).
  * WII: Don't init overlay when RAM is beyond 72MB.
  * WII: Skip CRC calculation on content load, can improve load times of
    larger games by several seconds.
  * WINDOWS: Fall back to gl1 driver if accelerated GPU driver is unavailable.
  * WINDOWS: Allow winraw and xinput to work without dinput (needed for WinRT).
  * WINDOWS: Add MSVC2017 ARM desktop support.
  * UWP: Fix rewind by opting for slower codepath.
  * UWP: Fix relative path name issues when loading shaders.
  * UWP: Optimizations for VFS system.
- from version 1.7.6
  * ANDROID: Fix Xperia Play input binding.
  * CHEEVOS: Reset when hardcore mode is toggled.
  * CHEEVOS: Update the hashing methods to identify NES, SNES and Lynx games
    (more accurate and accepting headerless ROMs).
  * COMMON: Add new JSON playlist format.
  * COMMON: Fix playlist corruption when deleting items.
  * COMMON: Fix archive progress display calculation.
  * COMMON: Fix playlist entries appearing with previously used names.
  * COMMON: Fix screenshot filename with no core or content.
  * COMMON: Allow compiling without menu support.
  * CORE UPDATER: Allow sideloading cores from the menu.
  * CPU FILTERS: Add Normal2x filter.
  * CRT/LINUX: New Linux switching method partially implemented.
  * CRT/LINUX: Linux restore desktop resolution fixed.
  * CRT/LINUX: Monitor index switching and auto enumerate for
    output detection in Linux (still working on the windows method).
  * CRT/RASPBERRY PI: Initial support.
  * DATE: Add Date / Time style options.
  * DEBUGGING: Add an integrated crash handler for debug builds
    (see https://docs.libretro.com/tech/debugging)
  * DISCORD: Register the application name properly.
  * DISK CONTROL: Remember the last used folder / current active
    folder to make disk-swapping faster.
  * INPUT: Add new menu toggle (hold start button for 2 seconds)
  * INPUT: Fix arrow keys being incorrectly bound as numpad keys
  * INPUT/SDL: Flush the joypad events. Decreases cpu usage over
    time with the SDL joypad driver.
  * LOCALIZATION: Add Greek translation.
  * LOCALIZATION: Update German translation.
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Simplified Chinese translation.
  * LOCALIZATION: Update Spanish translation.
  * MENU: New "ozone" menu driver.
  * MENU: Only show CRT SwitchRes if video display server is
    implemented (Windows/Linux for now)
  * MENU: User Interface -> Appearance -> 'Menu Font Green/Blue Color'
    settings now work properly.
  * MENU: Add option to enable in-menu sound effects.
  * MENU/D3D: Scissoring support (will be used for Ozone and menu widgets).
  * MENU/QT/WIMP: Allow building with MSVC2017.
  * MENU/QT/WIMP: Add detailed file browser table.
  * MENU/QT/WIMP: New grid view implementation that is faster
    and loads thumbnails on-demand.
  * MENU/QT/WIMP: Thumbnail drag and drop support.
  * MENU/RGUI: Overhaul custom theme interface + add wallpaper support.
  * MENU/RGUI: Thumbnail support and thumbnail downscaling.
  * MENU: Hide password values.
  * MENU/SOUNDS: Implement in-menu sound effects (not enabled by
    default for now, still experimental).
  * MIDI: Add a Linux ALSA driver for MIDI.
  * NETPLAY: Force fast-save-states when netplay is enabled.
  * NETPLAY: Allow quick joining subsystem lobbies.
  * OSX: Initial CoreAudio V3 audio driver (not yet used in release builds).
  * OSX: OpenGL 3.2 Core support for cores.
  * PS2: Initial PlayStation2 port.
  * PS4: Initial PlayStation4 port.
  * RECORDING: Implement recording options in the menu complete
    with quality profiles, streaming, and proper file naming
  * SCANNER: Fix GDI disc scanning.
  * SHADERS: Fix auto shader preset loading on D3D10, D3D11, D3D12
  * SUBSYSTEM: Allow more than 10 subsystems
  * SUBSYSTEM: Cores that use subsystem for complex scenarios can
    now load content without starting a regular content first
  * SUBSYSTEM: Remember the last used folder to make loading
    subsystem type content faster
  * SWITCH/LIBNX: Improve touch scaling calculation.
  * SWITCH: Proper button labels.
  * TVOS: Initial tvOS port.
  * VULKAN: Fix RGUI crashing at startup.
  * VULKAN/RGUI: Enable 'Menu Linear Filter' option.
  * VULKAN: Fix secondary screens in overlays not working.
  * WAYLAND: Implement idle-inhibit support (needed for screensaver suspend).
  * WAYLAND: Fix fullscreen toggle.
  * WIIU: Initial netplay peer-to-peer support. Network information working.
  * WINDOWS/WSA: Network Information info is blank until first network operation.
  * WINDOWS: Fix an ancient bug that caused wrong mappings for keyboard arrows.
  * WINDOWS: Remember window size and position if so desired.
  * WINDOWS: SSL/TLS connections now work properly.
  * WINDOWS: Fall back to GDI driver if no accelerated graphics driver is found.
  * UWP: Initial UWP port.
  * VFS: Update to version 3.
  * XBONE: Initial Xbox One port.
  * XMB/OZONE: Add more icons
  * XMB: Add Automatic Inverted theme
  * ???: Easter Egg
- Clean up changelog file
- Stop enabling libxml2 support which has been removed upstream
  * Drop libxml2 build dependecy
  * Strip --enable-libxml2 from configure options
* Mon Oct 29 2018 Ismail Dönmez <idonmez@suse.com>
- Cleanup with spec-cleaner
* Sun Oct 28 2018 sean@suspend.net
- update to version 1.7.5
  * CAMERA: Fix Video4Linux2 driver that broke years ago
  * CONFIG: Add 'Reset to defaults' setting in Configurations.
    This will reset your config file to defaults
  * CHEATS: Add support for Rumble when increasing or decreasing by the rumble value
  * CHEATS: Add cheat variables to allow for updating large portions of memory
  * CHEEVOS: Prevent loading states before achievements are fully loaded
  * CRT: New porches and interlaced bug fix
  * CRT: New functionality, ability to switch between 15KHz and 31KHz
  * COMMON: Support for "OEM-102" key (usually '\' on Euro keyboards)
  * DISCORD: Add 'Ask to Join' Feature
  * EMSCRIPTEN: Add stb_font support
  * INPUT: Add new menu toggle combos 'L3 + R' and 'L + R' (useful for Switch)
  * IOS: Use safe area to account for notch for iPhone X and adjust main view
  * LOCALIZATION: Update Portugese / Brazilian translation
  * LOCALIZATION: Update Japanese translation
  * LOCALIZATION: Update Polish translation
  * LOCALIZATION: Update Spanish translation
  * MENU: Add dropdown lists for many settings
  * MENU: Fix crash that could happen when changing cores on Android
  * MENU/QT/WIMP: Add option to rename playlists
  * MENU/QT/WIMP: Add option to filter extensions inside archives
    when adding to a playlist
  * MENU/QT/WIMP: Rename playlist entries with 2 single clicks
  * MENU/QT/WIMP: Fix shader parameter checkboxes not working
  * METAL: Add screenshot support
  * NETPLAY: Save lobby details received back from server after first announcement
  * OPENGL/GLX: Implement Adaptive VSync - GLX_EXT_swap_control_tear
  * OPENGL/WGL: Implement Adaptive VSync - WGL_EXT_swap_control_tear
  * RUNAHEAD: Fix performance degradation that could happen over
    time. Fixed input IDs outside of range 0-35
  * SWITCH: Add stb_font support
  * SWITCH: Add Retro Achievements support
  * SWITCH: Add networking support
  * Add touchscreen support
  * Add OpenGL support
  * SWITCH: Merging of RetroNX Nintendo Switch port, based on libnx SDK
  * VULKAN: Fix race condition in threaded mailbox emulation
  * VULKAN: Maintenance fixes
  * WIIU: Fix menu lag when built with DevKitPro r32
* Tue Aug  7 2018 mardnh@gmx.de
- Build with supoort for the WIMP Qt GUI
* Sun Jun 24 2018 boris@steki.net
- update to version 1.7.3
  * AUDIO: Audio mixer supports FLAC/MP3 file types now!
  * COMMON: Fixed bug 'crashing in cores that don't range check
    retro_set_controller_type'. Some people were having crashes
    when device is set to RETRO_DEVICE_NONE and the cores don't
    check the number of ports, in VBAM's case it was overflowing
    and crashing. QuickNES was crashing too.
  * COMMON: Fixed buffer overflow in url encoding (affecting MSVC2010/2013).
  * COMMON: (QuickMenu) Added Configuration Override submenu.
  * HID: Merge new HID subsystem.
  * HID: Fix WaveBird support for the Wii U GCA.
  * HID/OSX: Fix regression with IODHIDManager - gamepads which are
    connected later would not be autoconfigured.
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Portuguese translation.
  * MENU: New WIMP Qt GUI!
  * MENU: Audio mixer now works in the menu without any cores loaded.
    You have to enable the setting 'Enable menu audio' for this to work.
  * REMAPPING/OVERLAYS: Fix regression - overlays could no longer be remapped.
  * SCANNER: Add Wii Backup File WBFS support.
  * X11: CRT SwitchRes support for X11/Linux.
  * ANDROID/OPENSL: Prevent crashes when setting audio latency too low
    (buffer count can never be lower than 2 now).
  * CRT: Added CRT SwitchRes.
  * COMMON: Hide the 'Core delete' option if the 'Core updater' is also hidden.
  * COMMON: Add way to reset core association for playlist entry.
  * COMMON: Fix invalid long command line options causing infinite loop on Windows
  * COMMON: Add OSD statistics for video/audio/core.
  * COMMON: Added runahead system; allows you to drive down latency even further.
  * COMMON: Fix buggy behavior that could happen with ZIP file reading
    on some platforms as a result of not initializing struct.
  * CHEEVOS: Support Atari 2600, Virtual Boy, and Arcade (only Neo Geo,
    CPS-1, CPS-2 and CPS-3 and only with fbalpha core).
  * CHEEVOS: Add option to automatically take a screenshot when
    an achievement is triggered.
  * CHEEVOS: Fixed incompatibilities with Neo Geo Pocket achievement sets.
  * CHEEVOS: Store only login token, not password.
  * D3D10: Added D3D10 driver to release build. Has working shaders (Slang),
    overlay, and menu display driver support. Should be on par capabilities
    wise with D3D11 driver except for there being no hardware rendering right now.
  * D3D11: Experimental hardware renderer. Allows for libretro
    cores to use D3D11 for hardware rendering. First core to use this is PPSSPP.
  * D3D11: Increase backwards compatibility, shaders compile with Shader Model
    4.0 now, added support for more feature levels.
  * D3D10/D3D11/D3D12: Fix crashes with completely black
    or white thumbnail textures in XMB.
  * GUI: Support disabling window decorations on Windows and Linux.
  * LIBRETRO: Addition - Functions to enable and disable audio and
    video, and an environment function to query status of audio and video enables.
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Polish translation.
  * MENU: Add Rewind/Latency/Overlay settings to Quick Menu, add options
    to show/hide them (User Interface -> Views -> Quick Menu)
  * MENU/RGUI: Only show Menu Linear Filter for RGUI and only show it
    for video drivers that implement it (D3D8/9/10/11/12/GL)
  * MENU/RGUI: Add User Interface -> Appearance options.
  * MENU/RGUI: D3D8/D3D9: Hookup Menu Linear Filter
  * MENU/XMB: Disable XMB shadow icons by default for PowerPC and ARM for performance reasons.
  * MENU/XMB: Left/right thumbnails are now automatically scaled according to layout.
  * MENU/XMB: Add Left Thumbnails (additional to the right).
  * MENU/XMB: Fixed left/right tab regression.
  * MENU/XMB: Fix scaling of tall images that were cut on bottom previously.
  * MENU/XMB: Menu scale factor setting now changes texts length, image scaling and margins.
  * MENU/XMB: Mouse cursor scales correctly now.
  * MENU/XMB: Add toggle to show/hide Playlist tabs.
  * MENU/XMB: Add menu layout - can switch between Desktop, Handheld and Auto.
  * MENU/XMB: Don't load menu pipeline shaders unless XMB is
    selected (D3D10/D3D11/D3D12/GL/Vulkan)
  * MENU/VIDEO: Only show black frame insertion for the video drivers/context
    drivers that support it (so far this includes - D3D8/D3D9, OpenGL, Vulkan)
  * MENU/VIDEO: Only show max swapchain images if supported by video driver and/or context driver
    (so far this includes - DRM EGL context driver, VideoCore EGL context driver, Vulkan)
  * MENU/MaterialUI: Automatic DPI Scaling should be much improved now,
    now scales as expected at 1440p and 4K resolutions.
  * MENU/MaterialUI: Fix wrong calculation of an entry height
    causing long playlists to end up outside of screen range.
    This also could cause crashes on low DPI screens.
  * IOS: Fixed crash when opening downloaded roms from Safari or using the "Open in.." functionality.
    Added the compiler flag to support keyboard remapping to controls.
  * IOS: Fixed buffer overlap that caused a crash while trying to download GLSL shaders from the buildbot.
  * PS3: fix URLS
  * REMAPS: Mapping keyboard keys from more than one gamepad (works with dosbox)
  * REMAPS: Mapping more than one button to the same action
  * REMAPS: Unmapping buttons
  * REMAPS: Unmapping analogs
  * REMAPS: Mapping a button to trigger an analog response (tested with mupen, can
    run on SM64 with the d-pad now, triggers a full analog tilt)
  * REMAPS: Mapping an analog to another analog (having more than one
    analog mapped to the same output causes issues)
  * REMAPS: Mapping an analog to produce a button response
  * SCANNER: Should be able to scan dual-layer Wii disc images now,
    filestream code now supports files larger than 4GB.
  * SHADERS/SLANG: Slang shaders should work again on Android version
    and MSVC versions (basically all the Griffin-based versions).
  * SHADERS: If GL context is GLES2/3/Core context, Cg shaders are unavailable.
    Applies to shader list too.
  * SHADERS: Hide cg/glsl shaders from being able to be selected if
    D3D8/9/10/11/Vulkan video drivers are selected.
  * SHADERS: Hide slang shaders from being able to be selected if
    D3D8/9/OpenGL video drivers are selected.
  * SHADERS: Prevent crashes from occurring if we have the GL video driver
    in use and we try to skip to a slang shader through next/previous hotkeys
  * SHADERS: Fix shader parameter increase / decrease functions
  * SUBSYSTEM: handle savestates properly (cart1 + cart2.state0)
  * VULKAN/X11: Fix X11 Vulkan bug from Wayland driver.
  * VULKAN: Fix multi-line text spacing in menus with Vulkan driver.
  * WINDOWS XP: Add Cheevos support.
  * WINDOWS/MSVC 2003/2005/2010/2013/2015/2017: Add Cheevos support.
  * VITA: Bugfix for 'PS Vita takes many time to start to accept input' issue.
  * X11: Allow compositor disabling on X11 fullscreen through _NET_WM_BYPASS_COMPOSITOR
  * X11: Prioritize NET_WM_STATE_FULLSCREEN in true fullscreen mode
  * WIIU: Fix OOB read/write in keyboard driver.
* Mon Mar 26 2018 igarcia@suse.com
- Updated to version 1.7.1
  – 3DS: Now correctly reports amount of CPU cores.
  * 3DS: Frontend rating is now correctly implemented for both New 3DS/2DS and Old 3DS/2DS.
  * 3DS: Initial networking support, HTTP requests won’t work yet.
  * 3DS: Now reports memory and battery state.
  * AUDIO: Added ‘Audio Resampler Quality’ setting to Audio Settings. Setting
    this higher will increase sound quality at the expense of sound latency
    and/or performance. Setting this value lower will improve sound latency/
    performance at the expense of sound quality. Only has an effect if the
    Sinc resampler is used, and you have to restart the game for changes to take effect.
  * CHEEVOS: Fix unofficial achievements not being loaded.
  * CHEEVOS: Show savestate menu entries when no achievements are
    found even if hardcore mode is enabled.
  * CHEEVOS: Support Neo Geo Pocket.
  * COMMON: Bugfix for issue related to ‘Windows mouse pointer visible
    when running MESS or MAME cores’.
  * COMMON: Fix bug ‘Last item in a Playlist is ignored’.
  * COMMON: New LED API. Driver implemented for Raspberry Pi, proof of
    concept implemented for core MAME 2003.
  * COMMON: Add quick menu option to watch shader files for changes and
    recompile them automatically (Linux only for now).
  * D3D8: Direct3D 8 can now work on systems that have Direct3D 8 installed.
  * D3D9: Add menu support for MaterialUI/XMB.
  * D3D10: Initial video driver implementation.
  * D3D11: Initial video driver implementation.
  * D3D11: SPIRV-Cross/slang shader support for D3D11.
  * D3D12: Initial video driver implementation.
  * DINPUT: don’t reinitialize input driver on network events /
    media insertion / network drive connection
  * INPUT: show friendly names when available under input binds and system information
  * INPUT: show the config name when available under system information
  * GUI: Allow changing menu font color.
  * GUI: Menu visibility options for RGUI and MaterialUI.
  * GUI/MaterialUI: Works now with D3D8, D3D9 Cg, D3D11 and D3D12 drivers.
  * GUI/XMB: Add Monochrome Inverted icon theme.
  * GUI/XMB: Allow changing menu scale to 200%%.
  * GUI/XMB: Works now with D3D8, D3D9 Cg, D3D11 and D3D12 drivers.
    Menu shader effects currently don’t work on D3D8/D3D9 Cg.
  * HAIKU: Restored port.
  * KEYMAPPER: prevent a condition that caused input_menu_toggle to stop
    working when a RETRO_DEVICE_KEYBOARD type device is enabled
  * GL: ignore hard gpu sync when fast-forwarding
  * IOS10/11: Handle hardware keyboards and iCade controllers
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Portuguese-Brazilian translation.
  * LOCALIZATION: Update Spanish translation.
  * NETPLAY: Add menu option to select different MITM (relay) server locations.
  * OSX: Modify HID buttons detection algorithm.
  * QB: Added –datarootdir.
  * QB: Added –bindir and –mandir and deprecated –with-bin_dir and –with-man_dir.
  * QB: Added –docdir.
  * SHADERS: Allow saving of shader presets based on the parent directory
    (Saving one for */foo/bar/mario.sfc* would result in *shaders/presets/corename/bar.ext*).
    We decided it’s safer to still isolate the presets to a single core
    because different cores may treat video output differently.
  * SHADERS: Don’t save the path to the current preset to the main config.
    This was causing weird behavior, instead it will try to load *currentconfig.ext*
    and it will save a preset with that name when select *apply shader preset*.
    The resulting shader will restore properly after restarting and even
    after core/parent/game specific presets are loaded
  * SOLARIS: Initial port.
  * SWITCH: Initial Nintendo Switch port, based on libtransistor SDK.
  * PS3: Enable Cheevos.
  * PSP: Enable threading support through pthreads.
  * SHADERS: SPIRV-Cross/slang shader support for D3D11.
  * SHIELD ATV: Allow the remote / gamepad takeover hack to work with the 2017 gamepad
  * SUBSYSTEM: Subsystem saves now respect the save directory
  * SUBSYSTEM: You can now load subsystem games from the menu
    (see https://github.com/libretro/RetroArch/pull/6282 for caveats)
  * VULKAN: Fix swapchain recreation bug on Nvidia GPUs with Windows 10
    (resolved in Windows Nvidia driver version 390.77).
  * WINDOWS: Improved Unicode support (for cores/directory creation and 7zip archives).
  * WINDOWS: Show progress meter on taskbar for downloads (Windows 7 and up).
  * WINDOWS: WS_EX_LAYERED drastically decreases performance, so only
    set it when needed (transparency in windowed mode).
  * WIIU: Overlay support.
  * WIIU: Transparency support in menu + overlays.
  * WIIU: Increased stability during core switching.
  * WIIU: Shader support.
  * WIIU: Menu shader effects added (shaders).
  * WIIU: Add missing time/clock support. (also fixes RTC [Real Time Clock] in Gambatte)
  * XBOX OG: Restored port.
* Fri Dec 29 2017 igarcia@suse.com
- Updated to version 1.7.0
  * CHEEVOS: Add badges for achievements, shows thumbnail images of achievements.
  * CHEEVOS: Leaderboard support.
  * CHEEVOS: Only disable savestates on hardcore mode if achievements are not available.
  * COMMANDLINE: Fix fullscreen toggle switch.
  * COMMON: Add 'Automatically Load Content To Playlist' feature, enabled by default.
  * COMMON: Fix slowmotion ratio always being reset back to 1.
  * COMMON: Optimized NBIO implementations now for Apple, Windows, and Linux.
    Uses mmap for Linux/Windows/BSD if/when available. File I/O should now
    be much faster for loading images inside the menu.
  * COMMON: Native Blissbox support now for latest firmware as of writing (2.0).
    Implementation through libusb and/or native Windows HID.
  * COMMON: New lightgun API.
  * COMMON: New VFS (Virtual File System) API.
  * COMMON: Fixed some playlist bugs.
  * COMMON: New snow shader.
  * COMMON: Fix Quick Menu title, no longer shows 'Select File'.
  * COMMON: Fix loading cores that require no content one after another.
  * COMMON: Map Delete key to Y button for non-unified menu keyboard controls.
  * COMMON: Fix for relative paths being normalised and generating a duplicate history entry.
  * EMSCRIPTEN: Fix references to browserfs.
  * FREEBSD: Support libusb HID input driver.
  * HAIKU: Buildfix.
  * INPUT: Map clear button to DEL key.
  * LINUX/X11: Add RetroArch logo to window title bar.
  * LINUX/X11: Input driver now supports new lightgun code.
  * LINUX/X11: Support window transparency (requires a compositing window manager).
  * LOBBIES: Fix for crash on join netplay rooms via touch / glui.
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Portuguese-Brazilian translation.
  * LOCALIZATION: Update Polish translation.
  * LOCALIZATION: Update Russian translation.
  * MENU: Snowflake menu shader effect.
  * OSX/PPC: Fix the GL2 renderchain, had to use EXT
    versions of framebuffer/renderbuffer functions.
  * PS3: HTTP requests / downloads should now work.
  * PS3: Core Updater now works.
  * PS3: Improved font rendering, enable STB Unicode font renderer.
  * PSP: Make it work with Vita's Adrenaline.
  * PSP: Fix audio sync.
  * PSP: Fix content loading, port should be functional again.
  * PSP: Use 64MB when available.
  * SCANNER: Fix crash from Windows-incompatible format string.
  * VITA: Improve packaging, installation times.
  * WIIU: Disabled the controller patcher for now since it was
    the source of many stability issues.
  * VULKAN: Various stability fixes for WSI.
  * WINDOWS: Add MSVC 2017 solution.
  * WINDOWS: Get rid of the empty console window in MSVC 2010 builds.
  * WINDOWS: Raw input driver now supports new lightgun code.
  * WINDOWS: Use configured OSD/text message color on GDI driver.
  * WINDOWS/XINPUT: Populate XInput VID/PID from DInput so
    autoconfig doesn't rely solely on joypad names
  * WINDOWS/XINPUT: Fix crash that occurs in some situations with
    Steam running and a Steam Controller plugged in.
  * WINDOWS: Improve version reporting under System Information.
  * WINDOWS: Support window transparency.
  * WINDOWS: Correct usage of GetWindowPlacement per MS docs,
    fixes game window position on Win95/98.
  * WINDOWS: Added Visual Studio 2017 support.
* Wed Dec 13 2017 igarcia@suse.com
- Updated to version 1.6.9
  * COMMON: Small memory leak.
  * NETPLAY: Fix network command only working once.
- Changes from 1.6.8:
  * Audio: Fix the Audio DSP picker
  * CHEEVOS: Add support for RetroAchievements Leaderboards.
  * GUI: (MaterialUI) Skip querying and drawing items that are not
    visible; Cache content height and bbox calculation.
  * GUI: (MaterialUI) Fix entry box highlight calculation.
  * GUI: (XMB) Skip drawing the fading list when it is already transparent. Optimization.
  * GUI: (XMB) Comment out visible item calculation in xmb_draw_items().
  * GUI: (RGUI) Prevent crashes when using a non-English language reliant on UTF8.
  * GUI: Add menu option for OSD background color.
  * GUI: Add menu option for OSD text color.
  * GUI: Add menu option to remove frame count from OSD.
  * GUI: Allow wraparound of int/float settings when pressing the left key
  * INPUT/LIBRETRO: Add support for more mouse buttons (buttons 4/5)
  * INPUT/LIBRETRO: Add support for analog buttons
  * INPUT: Always show the controls menu even if descriptors are not set
  * INPUT: Fix input descriptors not being set on cores that
    don't implement the controllers interface
  * INPUT: Apply descriptors only for the amount of cores the core supports
  * INPUT: Implement keyboard to gamepad input remapping
    (limited to one gamepad device for now)
  * INPUT: Fix absolute mouse move handling on the winraw driver
  * INPUT: Ignore keyboard input if window is not active on udev driver
  * INPUT: Sanitize the filenames of autoconfig profiles before saving
  * LOBBIES: Fix crash on navigating left / right from the lobby menu
  * LOCALIZATION: Update Dutch translation
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Portuguese-Brazilian translation.
  * LOCALIZATION: Update Russian translation.
  * LINUX/ARMHF: Set buildbot updater URL to armhf location instead of blank string
  * LINUX/PI: Broadcom VC4: Add Videocore config option
  * LINUX/UDEV: Fix - RetroArch reads keyboard input when not focused with the udev input driver.
  * NETPLAY: Fix disconnection not fully deinitializing Netplay.
  * NETPLAY: Fix lan rooms when there is more than one room
  * NETPLAY: Fix lan rooms on systems where all addresses are treated as IPv6
  * COMMON: Fix clear/free loop conditionals in playlists.
  * WINDOWS/GDI: Fix flickering of text.
  * WINDOWS/GDI: Fix graphics corruption on Windows 98
  * WINDOWS/GDI: Allow compiling without DirectInput8 for NT support
  * WINDOWS/WGL: Try to use wglSwapLayerBuffers instead of
    SwapBuffers if possible (for more optimal performance).
  * WINDOWS: Fix menubar text corruption on Japanese locale systems
  * WINDOWS: Support Unicode file I/O (can now display CJK
    characters in file browser for example).
  * WINDOWS: Support Windows 95, NT3.51, NT4
  * WINDOWS: add Makefile.griffin targets for msvc6,2003,2005,2010,2012,2013
  * WII: Use custom, embedded libogc SDK.
  * WIIU: Initial touchscreen support for WiiU gamepad.
  * WIIU: Add Cheevos support.
  * SCANNER: Fix archive scanning.
  * SCANNER: Support CHD files.
  * SCANNER: Support Gamecube ISO scanning.
  * SCANNER: Use primary data track of disc images for CRC lookups rather than
    cue files. This is slower but finds matches more reliably, and is necessary
    for CHD files to work at all. Update your databases!
  * SCANNER: Fall back on looking inside archives when matching MAME/FBA content
    (most recent cores only). If you had difficulty with content being detected
    before, you may have better luck now. Update your databases and core info!
* Wed Aug 23 2017 glmarques.info@gmail.com
- Updated to version 1.6.7
  * NOTE: This is a bugfixed and spit-and-polish update. The initial release
    notes below are still from the 1.6.6 release.
  General changelog
  * SCANNER: Fix directory scanning.
  * SCANNER: Fix file scanning.
  * COMMON: Fix ‘Disk Image Append’ option.
  * FREEBSD: Compatibility fixes for Video4Linux2 camera driver.
  * GUI: (MaterialUI) Add disk image append icons.
  * GUI: (MaterialUI) Improve word wrapping when menu icons are enabled.
  * GUI: (MaterialUI) Add User Interface -> Appearance -> Menu Icons Enable.
    You can turn on/off the icons on the lefthand side of the menu entries.
  * GUI: Performance optimizations for XMB menu driver – only calculates visible items.
  * LOCALIZATION: Update Italian translation.
  Core updates since previous version (1.6.6)
  * Picodrive should hopefully work now again on Android after notaz‘ updates.
  * Beetle PSX’s OpenGL renderer should now work on various AMD GPUs thanks
    to rz5‘s efforts. There were previously some black screen issues on certain non-Polaris AMD GPUs.
  * Beetle PSX – Fixed bugs (geometry updates had max width and height unset, other ones) (by albertofustinoni).
  * Beetle Saturn – Unloading game leaves core unusable fix (by albertofustinoni).
  * Beetle Supergrafx – add turbo on/off for 2-button controller mode (by retrowertz).
  * Prosystem – NTSC Color Palette updates and DB updates (by underball).
* Fri Aug 11 2017 glmarques.info@gmail.com
- Updated to version 1.6.4
  General changelog
  * ANDROID: Fire Stick & Fire TV remote overrides gamepad port 0
    on button press and viceversa like SHIELD devices
  * ANDROID: Provide default save / system / state / screenshot locations
  * AUDIO: Audio mixer supports MOD/S3M/XM file types now!
  * INPUT: input swap override flag (for remotes) is cleared correctly
  * INPUT: allow specifying libretro device in remap files
  * INPUT: allow specifying analog dpad mode in remap files
  * INPUT: allow saving libretro device to remap files
  * INPUT: allow saving analog dpad mode to remap files
  * INPUT: allow removing core and game remap files from the menu
  * COMMON: Cores can now request to set a ‘shared context’. You no
    longer need to explicitly enable ‘Shared Hardware Context’
    for Citra/OpenLara/Dolphin.
  * COMMON: Add ‘Delete Core’ option to Core Information menu.
  * COMMON: Allow Max Timing Skew to be set to 0.
  * COMMON: Change the “content dir” behavior so it works on either a
    flag or an empty directory setting, now platform drivers can provide
    defaults for save / system / state / screenshot dirs and still allow
    the content dir functionality, these settings are under settings /
    saving and flagged as advanced
  * GUI: You can turn on/off ‘Horizontal Animation’ now for the XMB menu.
    Turning animations off can result in a performance boost.
  * GUI: Fix sublabel word-wrapping in XMB where multi-byte languages were cut off too soon
  * LOCALIZATION: Update Dutch translation
  * LOCALIZATION: Update Traditional Chinese translation
  * LOCALIZATION: Update Italian translation
  * LOCALIZATION: Update Russian translation
  * WINDOWS: Provide default save / system / state / screenshot locations
  * LOBBIES: Show what country the host is in
  * MENU: Enable OSD text rendering for gdi and libcaca drivers
  * WINDOWS 98/ME/2K: Set default directory for MSVC 2005 RetroArch version.
  * WII: Better V-Sync handling, backported from SuperrSonic.
  * WIIU: Exception handler rewritten.
* Thu Jul  6 2017 igarcia@suse.com
- Add version 1.6.1
